@@ -113,7 +113,7 @@ void TestEkosMeridianFlip::testGuidingMF()
 void TestEkosMeridianFlip::testCaptureMF()
 {
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(10, false, true));
+    QVERIFY(prepareCaptureTestcase(10, false, true, false));
 
     // start capturing
     QVERIFY(startCapturing());
@@ -143,7 +143,7 @@ void TestEkosMeridianFlip::testCaptureMF()
 void TestEkosMeridianFlip::testCaptureMFAbortWaiting()
 {
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(10, false, false));
+    QVERIFY(prepareCaptureTestcase(10, false, false, false));
 
     // start capturing
     QVERIFY(startCapturing());
@@ -170,7 +170,7 @@ void TestEkosMeridianFlip::testCaptureMFAbortWaiting()
 void TestEkosMeridianFlip::testCaptureMFAbortFlipping()
 {
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(10, false, false));
+    QVERIFY(prepareCaptureTestcase(10, false, false, false));
 
     // start capturing
     QVERIFY(startCapturing());
@@ -201,7 +201,7 @@ void TestEkosMeridianFlip::testCaptureMFAbortFlipping()
 void TestEkosMeridianFlip::testCaptureGuidingMF()
 {
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(15, true, true));
+    QVERIFY(prepareCaptureTestcase(15, true, true, false));
 
     // start guiding
     QVERIFY(startGuiding(2.0));
@@ -235,8 +235,11 @@ void TestEkosMeridianFlip::testCaptureGuidingMF()
 
 void TestEkosMeridianFlip::testCaptureAlignMF()
 {
+    if (!astrometry_available)
+        QSKIP("No astrometry files available to run test");
+
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(45, false, true));
+    QVERIFY(prepareCaptureTestcase(45, false, true, false));
 
     // start alignment
     QVERIFY(startAligning(5.0));
@@ -267,8 +270,11 @@ void TestEkosMeridianFlip::testCaptureAlignMF()
 
 void TestEkosMeridianFlip::testCaptureAlignGuidingMF()
 {
+    if (!astrometry_available)
+        QSKIP("No astrometry files available to run test");
+
     // set up the capture sequence
-    QVERIFY(prepareCaptureTestcase(40, true, true));
+    QVERIFY(prepareCaptureTestcase(40, true, true, false));
 
     // start alignment
     QVERIFY(startAligning(5.0));
@@ -317,7 +323,7 @@ void TestEkosMeridianFlip::testCaptureAlignGuidingMF()
 
 void TestEkosMeridianFlip::testSimpleMF_data()
 {
-    prepareTestData({"Luminance"}, {false}, {false}, {false});
+    prepareTestData(18.0, {"Luminance"}, {false}, {false}, {false});
 }
 
 void TestEkosMeridianFlip::testSimpleMFDelay_data()
@@ -327,18 +333,18 @@ void TestEkosMeridianFlip::testSimpleMFDelay_data()
 
 void TestEkosMeridianFlip::testGuidingMF_data()
 {
-    prepareTestData({"Luminance"}, {false}, {false}, {false});
+    prepareTestData(18.0, {"Luminance"}, {false}, {false}, {false});
 }
 
 void TestEkosMeridianFlip::testCaptureMF_data()
 {
-    prepareTestData({"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false, true}, {false, true}, {false});
+    prepareTestData(18.0, {"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false, true}, {false, true}, {false});
 }
 
 void TestEkosMeridianFlip::testCaptureMFAbortWaiting_data()
 {
     // no tests for focusing and dithering
-    prepareTestData({"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false}, {false}, {false});
+    prepareTestData(18.0, {"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false}, {false}, {false});
 }
 
 void TestEkosMeridianFlip::testCaptureMFAbortFlipping_data()
@@ -348,7 +354,7 @@ void TestEkosMeridianFlip::testCaptureMFAbortFlipping_data()
 
 void TestEkosMeridianFlip::testCaptureGuidingMF_data()
 {
-    prepareTestData({"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false, true}, {false, true}, {false, true});
+    prepareTestData(18.0, {"Luminance", "Red,Green,Blue,Red,Green,Blue"}, {false, true}, {false, true}, {false, true});
 }
 
 void TestEkosMeridianFlip::testCaptureAlignMF_data()
