@@ -79,7 +79,8 @@ class KSUserDB
          ************************************************************************/
 
         void AddDarkFrame(const QVariantMap &oneFrame);
-        bool DeleteDarkFrame(const QString &filename);
+        void UpdateDarkFrame(const QVariantMap &oneFrame);
+        void DeleteDarkFrame(const QString &filename);
         void GetAllDarkFrames(QList<QVariantMap> &darkFrames);
 
 
@@ -379,5 +380,5 @@ class KSUserDB
         /** XML reader for importing old formats **/
         QXmlStreamReader *reader_ { nullptr };
 
-        static const uint16_t SCHEMA_VERSION = 306;
+        static const uint16_t SCHEMA_VERSION = 307;
 };
