@@ -143,6 +143,13 @@ class Align : public QWidget, public Ui::Align
             OBJECT_FIXED_GRID
         };
 
+        typedef enum
+        {
+            ALIGN_RESULT_SUCCESS,
+            ALIGN_RESULT_WARNING,
+            ALIGN_RESULT_FAILED
+        } AlignResult;
+
         /** @defgroup AlignDBusInterface Ekos DBus Interface - Align Module
              * Ekos::Align interface provides advanced scripting capabilities to solve images using online or offline astrometry.net
             */
@@ -477,8 +484,9 @@ class Align : public QWidget, public Ui::Align
              * @param ra Center RA in solved image, degrees.
              * @param dec Center DEC in solved image, degrees.
              * @param pixscale Image scale is arcsec/pixel
+             * @param eastToTheRight When the image is rotated, so that North is up, East would be to the right.
              */
-        void solverFinished(double orientation, double ra, double dec, double pixscale);
+        void solverFinished(double orientation, double ra, double dec, double pixscale, bool eastToTheRight);
 
         void solverComplete();
 
@@ -547,6 +555,7 @@ class Align : public QWidget, public Ui::Align
         void setPAHSlewDone();
         void setPAHCorrectionSelectionComplete();
         void zoomAlignView();
+        void setAlignZoom(double scale);
 
         // Align Settings
         QJsonObject getSettings() const;
@@ -570,6 +579,7 @@ class Align : public QWidget, public Ui::Align
 
         // Solver timeout
         void checkAlignmentTimeout();
+        void setAlignTableResult(AlignResult result);
 
         void updateTelescopeType(int index);
 
@@ -577,6 +587,12 @@ class Align : public QWidget, public Ui::Align
         void showFITSViewer();
         void toggleAlignWidgetFullScreen();
 
+        /**
+         * @brief prepareCapture Set common settings for capture for align module
+         * @param targetChip target Chip
+         */
+        void prepareCapture(ISD::CCDChip *targetChip);
+
         // Polar Alignment Helper slots
 
         void rotatePAH();
@@ -753,7 +769,7 @@ class Align : public QWidget, public Ui::Align
         /**
              * @brief processPAHStage After solver is complete, handle PAH Stage processing
              */
-        void processPAHStage(double orientation, double ra, double dec, double pixscale);
+        void processPAHStage(double orientation, double ra, double dec, double pixscale, bool eastToTheRight);
 
         void resizeEvent(QResizeEvent *event) override;
 
