@@ -85,14 +85,38 @@ OpsAstrometryIndexFiles::OpsAstrometryIndexFiles(Align *parent) : QDialog(KStars
             label->setVisible(false);
         }
     }
+
+    connect(addIndexFileDirectory, &QAbstractButton::clicked, this, [this]()
+    {
+        QString dir = QFileDialog::getExistingDirectory(this, "Load Index File Directory",
+                      QDir::homePath(),
+                      QFileDialog::ShowDirsOnly
+                      | QFileDialog::DontResolveSymlinks);
+        if (dir.isEmpty())
+            return;
+        addDirectoryToList(dir);
+    });
+    connect(removeIndexFileDirectory, &QAbstractButton::clicked, this, [this]()
+    {
+        if(indexLocations->currentIndex() != 0)
+            removeDirectoryFromList(indexLocations->currentText());
+    });
+
+
 }
 
 void OpsAstrometryIndexFiles::showEvent(QShowEvent *)
 {
+    updateIndexDirectoryList();
+
+}
+
+void OpsAstrometryIndexFiles::updateIndexDirectoryList()
+{
+    // This is needed because they might have directories stored in the config file.
+    // So we can't just use the options folder list.
     QStringList astrometryDataDirs = KSUtils::getAstrometryDataDirs();
 
-    if (astrometryDataDirs.count() == 0)
-        return;
     indexLocations->clear();
     if(astrometryDataDirs.count() > 1)
         indexLocations->addItem("All Sources");
@@ -100,6 +124,32 @@ void OpsAstrometryIndexFiles::showEvent(QShowEvent *)
     slotUpdate();
 }
 
+void OpsAstrometryIndexFiles::addDirectoryToList(QString directory)
+{
+    QDir dir(directory);
+    if(!dir.exists())
+        return;
+    QString directoryPath = dir.absolutePath();
+
+    QStringList indexFileDirs = Options::astrometryIndexFolderList();
+    if(indexFileDirs.contains(directoryPath))
+        return;
+    indexFileDirs.append(directoryPath);
+    Options::setAstrometryIndexFolderList(indexFileDirs);
+    updateIndexDirectoryList();
+}
+
+void OpsAstrometryIndexFiles::removeDirectoryFromList(QString directory)
+{
+    QStringList indexFileDirs = Options::astrometryIndexFolderList();
+    if(indexFileDirs.contains(directory))
+    {
+        indexFileDirs.removeOne(directory);
+        Options::setAstrometryIndexFolderList(indexFileDirs);
+        updateIndexDirectoryList();
+    }
+}
+
 void OpsAstrometryIndexFiles::slotUpdate()
 {
     QList<QCheckBox *> checkboxes = findChildren<QCheckBox *>();
@@ -123,10 +173,10 @@ void OpsAstrometryIndexFiles::slotUpdate()
 
     QStringList nameFilter("*.fits");
 
-    if (Options::astrometrySolverIsInternal())
-        KSUtils::configureLocalAstrometryConfIfNecessary();
+    //    if (Options::astrometrySolverIsInternal())
+    //        KSUtils::configureLocalAstrometryConfIfNecessary();
 
-    QStringList astrometryDataDirs = KSUtils::getAstrometryDataDirs();;
+    QStringList astrometryDataDirs = Options::astrometryIndexFolderList();
 
     bool allDirsSelected = (indexLocations->currentIndex() == 0 && astrometryDataDirs.count() > 1);
     bool folderIsWriteable;
