@@ -47,7 +47,7 @@ void CustomProperties::syncProperties()
                                        << "GUIDER_EXPOSURE" << "FILTER_SLOT" << "TELESCOPE_TIMED_GUIDE_NS"
                                        << "TELESCOPE_TIMED_GUIDE_WE";
 
-    for (auto &property : currentCCD->getProperties())
+    for (auto &property : *currentCCD->getProperties())
     {
         const QString name = property->getName();
         // Skip empty properties
@@ -110,7 +110,7 @@ void CustomProperties::slotApply()
         QString numberLabel = jobPropertiesList->item(i)->text();
 
         // Match against existing properties
-        for(auto &indiProp : currentCCD->getProperties())
+        for(auto &indiProp : *currentCCD->getProperties())
         {
             // If label matches then we have the property
             if (indiProp->getType() == INDI_NUMBER && QString(indiProp->getLabel()) == numberLabel)
