@@ -40,9 +40,11 @@ static const QStringList guideStates = { I18N_NOOP("Idle"),
                                          I18N_NOOP("Manual Dithering"),
                                          I18N_NOOP("Dithering error"),
                                          I18N_NOOP("Dithering successful"),
-                                         I18N_NOOP("Settling")};
+                                         I18N_NOOP("Settling")
+                                       };
 
-typedef enum {
+typedef enum
+{
     GUIDE_IDLE,
     GUIDE_ABORTED,
     GUIDE_CONNECTED,
@@ -68,10 +70,11 @@ typedef enum {
 const QString &getGuideStatusString(GuideState state);
 
 // Capture States
-static const QStringList captureStates = {
+static const QStringList captureStates =
+{
     I18N_NOOP("Idle"), I18N_NOOP("In Progress"), I18N_NOOP("Capturing"), I18N_NOOP("Pause Planned"), I18N_NOOP("Paused"),
     I18N_NOOP("Suspended"), I18N_NOOP("Aborted"), I18N_NOOP("Waiting"), I18N_NOOP("Image Received"),
-    I18N_NOOP("Dithering"),I18N_NOOP("Focusing"), I18N_NOOP("Filter Focus"), I18N_NOOP("Changing Filter"),
+    I18N_NOOP("Dithering"), I18N_NOOP("Focusing"), I18N_NOOP("Filter Focus"), I18N_NOOP("Changing Filter"), I18N_NOOP("Guider Settling"),
     I18N_NOOP("Setting Temperature"), I18N_NOOP("Setting Rotator"), I18N_NOOP("Aligning"), I18N_NOOP("Calibrating"),
     I18N_NOOP("Meridian Flip"), I18N_NOOP("Complete")
 };
@@ -89,7 +92,8 @@ static const QStringList captureStates = {
   * - Waiting for start of capturing (@see CAPTURE_PAUSE_PLANNED, @see CAPTURE_PAUSED, @see CAPTURE_SUSPENDED and @see CAPTURE_WAITING)
   * - Capturing (@see CAPTURE_CAPTURING and @see CAPTURE_IMAGE_RECEIVED)
   */
-typedef enum {
+typedef enum
+{
     CAPTURE_IDLE,                /*!< no capture job active */
     CAPTURE_PROGRESS,            /*!< capture job sequence in preparation (temperature, filter, rotator) */
     CAPTURE_CAPTURING,           /*!< CCD capture running */
@@ -103,6 +107,7 @@ typedef enum {
     CAPTURE_FOCUSING,            /*!< focusing before starting to capture */
     CAPTURE_FILTER_FOCUS,        /*!< not used */
     CAPTURE_CHANGING_FILTER,     /*!< preparation event changing the filter */
+    CAPTURE_GUIDER_DRIFT,        /*!< preparation event waiting for the guider to settle */
     CAPTURE_SETTING_TEMPERATURE, /*!< preparation event setting the camera temperature */
     CAPTURE_SETTING_ROTATOR,     /*!< preparation event setting the camera rotator */
     CAPTURE_ALIGNING,            /*!< aligning before starting to capture */
@@ -116,9 +121,11 @@ const QString &getCaptureStatusString(CaptureState state);
 // Focus States
 static const QStringList focusStates = { I18N_NOOP("Idle"),    I18N_NOOP("Complete"),       I18N_NOOP("Failed"),
                                          I18N_NOOP("Aborted"), I18N_NOOP("User Input"),     I18N_NOOP("In Progress"),
-                                         I18N_NOOP("Framing"), I18N_NOOP("Changing Filter") };
+                                         I18N_NOOP("Framing"), I18N_NOOP("Changing Filter")
+                                       };
 
-typedef enum {
+typedef enum
+{
     FOCUS_IDLE,
     FOCUS_COMPLETE,
     FOCUS_FAILED,
@@ -134,9 +141,11 @@ const QString &getFocusStatusString(FocusState state);
 // Align States
 static const QStringList alignStates = { I18N_NOOP("Idle"),    I18N_NOOP("Complete"),    I18N_NOOP("Failed"),
                                          I18N_NOOP("Aborted"), I18N_NOOP("In Progress"), I18N_NOOP("Syncing"),
-                                         I18N_NOOP("Slewing") };
+                                         I18N_NOOP("Slewing")
+                                       };
 
-typedef enum {
+typedef enum
+{
     ALIGN_IDLE,
     ALIGN_COMPLETE,
     ALIGN_FAILED,
@@ -150,7 +159,8 @@ const QString &getAlignStatusString(AlignState state);
 
 // Filter Manager States
 static const QStringList filterStates = { I18N_NOOP("Idle"), I18N_NOOP("Changing Filter"), I18N_NOOP("Focus Offset"),
-                                          I18N_NOOP("Auto Focus")};
+                                          I18N_NOOP("Auto Focus")
+                                        };
 typedef enum
 {
     FILTER_IDLE,
@@ -159,6 +169,15 @@ typedef enum
     FILTER_AUTOFOCUS
 } FilterState;
 
+typedef enum
+{
+    SCRIPT_PRE_JOB,     /**< Script to run before a sequence job is started */
+    SCRIPT_PRE_CAPTURE, /**< Script to run before a sequence capture is started */
+    SCRIPT_POST_CAPTURE,/**< Script to run after a sequence capture is completed */
+    SCRIPT_POST_JOB,    /**< Script to run after a sequence job is completed */
+    SCRIPT_N
+} ScriptTypes;
+
 const QString &getFilterStatusString(FilterState state);
 
 // Scheduler states
@@ -166,9 +185,11 @@ const QString &getFilterStatusString(FilterState state);
 const QString &getSchedulerStatusString(AlignState state);
 
 static const QStringList schedulerStates = { I18N_NOOP("Idle"), I18N_NOOP("Startup"), I18N_NOOP("Running"),
-                                          I18N_NOOP("Paused"), I18N_NOOP("Shutdown"), I18N_NOOP("Aborted")};
+                                             I18N_NOOP("Paused"), I18N_NOOP("Shutdown"), I18N_NOOP("Aborted")
+                                           };
 
-typedef enum {
+typedef enum
+{
     SCHEDULER_IDLE,     /*< Scheduler is stopped. */
     SCHEDULER_STARTUP,  /*< Scheduler is starting the observatory up. */
     SCHEDULER_RUNNING,  /*< Scheduler is running. */
@@ -178,7 +199,8 @@ typedef enum {
     SCHEDULER_LOADING   /*< Scheduler is loading a schedule. */
 } SchedulerState;
 
-typedef enum {
+typedef enum
+{
     Idle,
     Pending,
     Success,
@@ -194,32 +216,32 @@ const int INVALID_VALUE = -1e6;
 
 // Communication Status
 Q_DECLARE_METATYPE(Ekos::CommunicationStatus)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::CommunicationStatus& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::CommunicationStatus &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::CommunicationStatus &dest);
 
 // Capture Status
 // FIXME is there a way to avoid unnecessary duplicating code? The solution suggested in KDE WiKi is to use Boost
 // which we do not have to add as dependency
 Q_DECLARE_METATYPE(Ekos::CaptureState)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::CaptureState& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::CaptureState &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::CaptureState &dest);
 
 // Focus
 Q_DECLARE_METATYPE(Ekos::FocusState)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::FocusState& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::FocusState &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::FocusState &dest);
 
 // Guide
 Q_DECLARE_METATYPE(Ekos::GuideState)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::GuideState& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::GuideState &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::GuideState &dest);
 
 // Align
 Q_DECLARE_METATYPE(Ekos::AlignState)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::AlignState& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::AlignState &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::AlignState &dest);
 
 // Scheduler
 Q_DECLARE_METATYPE(Ekos::SchedulerState)
-QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::SchedulerState& source);
+QDBusArgument &operator<<(QDBusArgument &argument, const Ekos::SchedulerState &source);
 const QDBusArgument &operator>>(const QDBusArgument &argument, Ekos::SchedulerState &dest);
