@@ -18,6 +18,7 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "ekos_debug.h"
+#include "fitsviewer/fitsview.h"
 
 #include <KActionCollection>
 #include <basedevice.h>
@@ -968,17 +969,19 @@ void Message::processPolarCommands(const QString &command, const QJsonObject &pa
         double x = payload["x"].toDouble();
         double y = payload["y"].toDouble();
 
-        if (boundingRect.isNull() == false)
+        if (m_BoundingRect.isNull() == false)
         {
             // #1 Find actual dimension inside the bounding rectangle
             // since if we have bounding rectable then x,y fractions are INSIDE it
-            double boundX = x * boundingRect.width();
-            double boundY = y * boundingRect.height();
+            double boundX = x * m_BoundingRect.width();
+            double boundY = y * m_BoundingRect.height();
 
             // #2 Find fraction of the dimensions above the full image size
             // Add to it the bounding rect top left offsets
-            x = (boundX + boundingRect.x()) / viewSize.width();
-            y = (boundY + boundingRect.y()) / viewSize.height();
+            // factors in the change caused by zoom
+            x = ((boundX + m_BoundingRect.x()) / (m_CurrentZoom / 100)) / m_ViewSize.width();
+            y = ((boundY + m_BoundingRect.y()) / (m_CurrentZoom / 100)) / m_ViewSize.height();
+
         }
 
         align->setPAHCorrectionOffsetPercentage(x, y);
@@ -991,6 +994,16 @@ void Message::processPolarCommands(const QString &command, const QJsonObject &pa
     {
         align->setPAHRefreshComplete();
     }
+    else if (command == commands[PAH_SLEW_DONE])
+    {
+        align->setPAHSlewDone();
+    }
+    else if (command == commands[PAH_PAH_SET_ZOOM])
+    {
+        double scale = payload["scale"].toDouble();
+        align->setAlignZoom(scale);
+    }
+
 }
 
 void Message::setPAHStage(Ekos::Align::PAHStage stage)
@@ -1207,6 +1220,15 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
 {
     QList<ISD::GDInterface *> devices = m_Manager->getAllDevices();
     QString device = payload["device"].toString();
+
+    // In case we want to UNSUBSCRIBE from all at once
+    if (device.isEmpty() && command == commands[DEVICE_PROPERTY_UNSUBSCRIBE])
+    {
+        m_PropertySubscriptions.clear();
+        return;
+    }
+
+    // For the device
     auto pos = std::find_if(devices.begin(), devices.end(), [device](ISD::GDInterface * oneDevice)
     {
         return (QString(oneDevice->getDeviceName()) == device);
@@ -1233,7 +1255,7 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
     else if (command == commands[DEVICE_GET])
     {
         QJsonArray properties;
-        for (const auto &oneProp : oneDevice->getProperties())
+        for (const auto &oneProp : *oneDevice->getProperties())
         {
             QJsonObject singleProp;
             if (oneDevice->getJSONProperty(oneProp->getName(), singleProp, payload["compact"].toBool(false)))
@@ -1253,21 +1275,74 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
     // When subscribed, the updates are immediately pushed as soon as they are received.
     else if (command == commands[DEVICE_PROPERTY_SUBSCRIBE])
     {
-        const QString property = payload["property"].toString();
+        const QJsonArray properties = payload["properties"].toArray();
+        const QJsonArray groups = payload["groups"].toArray();
+
+        // Get existing subscribed props for this device
         QSet<QString> props;
         if (m_PropertySubscriptions.contains(device))
             props = m_PropertySubscriptions[device];
-        props.insert(property);
+
+        // If it is just a single property, let's insert it to props.
+        if (properties.isEmpty() == false)
+        {
+            for (const auto &oneProp : properties)
+                props.insert(oneProp.toString());
+        }
+        // If group is specified, then we need to add ALL properties belonging to this group.
+        else if (groups.isEmpty() == false)
+        {
+            QVariantList indiGroups = groups.toVariantList();
+            for (auto &oneProp : *oneDevice->getProperties())
+            {
+                if (indiGroups.contains(oneProp->getGroupName()))
+                    props.insert(oneProp->getName());
+            }
+        }
+        // Otherwise, subscribe to ALL property in this device
+        else
+        {
+            for (auto &oneProp : *oneDevice->getProperties())
+                props.insert(oneProp->getName());
+        }
+
         m_PropertySubscriptions[device] = props;
     }
     else if (command == commands[DEVICE_PROPERTY_UNSUBSCRIBE])
     {
-        const QString property = payload["property"].toString();
+        const QJsonArray properties = payload["properties"].toArray();
+        const QJsonArray groups = payload["groups"].toArray();
+
+        // Get existing subscribed props for this device
+        QSet<QString> props;
         if (m_PropertySubscriptions.contains(device))
+            props = m_PropertySubscriptions[device];
+
+        // If it is just a single property, let's insert it to props.
+        // If it is just a single property, let's insert it to props.
+        if (properties.isEmpty() == false)
         {
-            QSet<QString> props = m_PropertySubscriptions[device];
-            props.remove(property);
+            for (const auto &oneProp : properties)
+                props.remove(oneProp.toString());
         }
+        // If group is specified, then we need to add ALL properties belonging to this group.
+        else if (groups.isEmpty() == false)
+        {
+            QVariantList indiGroups = groups.toVariantList();
+            for (auto &oneProp : *oneDevice->getProperties())
+            {
+                if (indiGroups.contains(oneProp->getGroupName()))
+                    props.remove(oneProp->getName());
+            }
+        }
+        // Otherwise, subscribe to ALL property in this device
+        else
+        {
+            for (auto &oneProp : *oneDevice->getProperties())
+                props.remove(oneProp->getName());
+        }
+
+        m_PropertySubscriptions[device] = props;
     }
 }
 
@@ -1432,10 +1507,11 @@ void Message::sendEvent(const QString &message, KSNotification::EventType event)
     sendResponse(commands[NEW_NOTIFICATION], newEvent);
 }
 
-void Message::setBoundingRect(QRect rect, QSize view)
+void Message::setBoundingRect(QRect rect, QSize view, double currentZoom)
 {
-    boundingRect = rect;
-    viewSize = view;
+    m_BoundingRect = rect;
+    m_ViewSize = view;
+    m_CurrentZoom = currentZoom;
 }
 
 void Message::processDialogResponse(const QJsonObject &payload)
