@@ -86,7 +86,8 @@ class GuideInterface : public QObject
         void newSNR(double snr);
         void calibrationUpdate(CalibrationUpdateType type, const QString &message = QString(""), double x = 0, double y = 0);
         void frameCaptureRequested();
-
+        void guideStats(double raError, double decError, int raPulse, int decPulse,
+                        double snr, double skyBg, int numStars);
         void guideEquipmentUpdated();
 
     protected:
