@@ -11,6 +11,10 @@
 
 #include "ui_opsguide.h"
 #include "guide.h"
+#include "stellarsolver.h"
+#include "ksutils.h"
+#include "kspaths.h"
+#include "ekos/auxiliary/stellarsolverprofileeditor.h"
 
 class KConfigDialog;
 
@@ -25,16 +29,19 @@ namespace Ekos
  */
 class OpsGuide : public QFrame, public Ui::OpsGuide
 {
-    Q_OBJECT
+        Q_OBJECT
 
-  public:
-    explicit OpsGuide();
-    virtual ~OpsGuide() override = default;
+    public:
+        explicit OpsGuide();
+        virtual ~OpsGuide() override = default;
+        void loadOptionsProfiles();
 
-  signals:
-    void settingsUpdated();
+    signals:
+        void settingsUpdated();
 
-  private:
-    KConfigDialog *m_ConfigDialog { nullptr };
+    private:
+        KConfigDialog *m_ConfigDialog { nullptr };
+        QList<SSolver::Parameters> optionsList;
+        StellarSolverProfileEditor *optionsProfileEditor { nullptr };
 };
 }
