@@ -28,6 +28,7 @@
 #include "indi/indistd.h"
 #include "mount/mount.h"
 #include "scheduler/scheduler.h"
+#include "analyze/analyze.h"
 #include "observatory/observatory.h"
 #include "auxiliary/filtermanager.h"
 #include "auxiliary/serialportassistant.h"
@@ -84,6 +85,7 @@ class Manager : public QDialog, public Ui::Manager
 
         Q_SCRIPTABLE Q_PROPERTY(CommunicationStatus indiStatus READ indiStatus NOTIFY indiStatusChanged)
         Q_SCRIPTABLE Q_PROPERTY(CommunicationStatus ekosStatus READ ekosStatus NOTIFY ekosStatusChanged)
+        Q_SCRIPTABLE Q_PROPERTY(CommunicationStatus settleStatus READ settleStatus NOTIFY settleStatusChanged)
         Q_SCRIPTABLE Q_PROPERTY(bool ekosLiveStatus READ ekosLiveStatus NOTIFY ekosLiveStatusChanged)
         Q_SCRIPTABLE Q_PROPERTY(QStringList logText READ logText NOTIFY newLog)
 
@@ -101,6 +103,10 @@ class Manager : public QDialog, public Ui::Manager
         }
         void addObjectToScheduler(SkyObject *object);
 
+        Scheduler *schedulerModule()
+        {
+            return schedulerProcess.get();
+        }
         Guide *guideModule()
         {
             return guideProcess.get();
@@ -133,6 +139,10 @@ class Manager : public QDialog, public Ui::Manager
         {
             return summaryPreview.get();
         }
+        FilterManager *getFilterManager()
+        {
+            return filterManager.data();
+        }
         QString getCurrentJobName();
         void announceEvent(const QString &message, KSNotification::EventType event);
 
@@ -243,6 +253,15 @@ class Manager : public QDialog, public Ui::Manager
             return m_ekosStatus;
         }
 
+        /**
+         * DBUS interface function.
+         * @return Settle status (0 Idle, 1 Pending, 2 Started, 3 Error)
+         */
+        Q_SCRIPTABLE CommunicationStatus settleStatus()
+        {
+            return m_settleStatus;
+        }
+
         /**
          * DBUS interface function. Toggle Ekos logging.
          * @param name Name of logging to toggle. Available options are:
@@ -306,6 +325,7 @@ class Manager : public QDialog, public Ui::Manager
         // Have to use full Ekos::CommunicationStatus for DBus signal to work
         void ekosStatusChanged(Ekos::CommunicationStatus status);
         void indiStatusChanged(Ekos::CommunicationStatus status);
+        void settleStatusChanged(Ekos::CommunicationStatus status);
         void ekosLiveStatusChanged(bool status);
 
         void newLog(const QString &text);
@@ -338,6 +358,7 @@ class Manager : public QDialog, public Ui::Manager
 
         void processNewDevice(ISD::GDInterface *);
         void processNewProperty(INDI::Property *);
+        void processDeleteProperty(const QString &name);
 
         void processNewNumber(INumberVectorProperty *nvp);
         void processNewText(ITextVectorProperty *tvp);
@@ -390,13 +411,14 @@ class Manager : public QDialog, public Ui::Manager
         void wizardProfile();
 
         // Mount Summary
-        void updateMountCoords(const QString &ra, const QString &dec, const QString &az, const QString &alt);
+        void updateMountCoords(const QString &ra, const QString &dec, const QString &az, const QString &alt, int pierSide,
+                               const QString &ha);
         void updateMountStatus(ISD::Telescope::Status status);
         void setTarget(SkyObject *o);
 
         // Capture Summary
         void updateCaptureStatus(CaptureState status);
-        void updateCaptureProgress(SequenceJob *job);
+        void updateCaptureProgress(SequenceJob *job, const QSharedPointer<FITSData> &data);
         void updateDownloadProgress(double timeLeft);
         void updateExposureProgress(SequenceJob *job);
         void updateCaptureCountDown();
@@ -478,6 +500,9 @@ class Manager : public QDialog, public Ui::Manager
         // All generic devices (i.e. those define by INDI server)
         QList<ISD::GDInterface *> genericDevices;
 
+        // All proxy devices (generated devices by Ekos Manager for specific interfaces)
+        QList<ISD::GDInterface *> proxyDevices;
+
         // All Managed devices (ie. those explicitly defined in the profile)
         QMap<DeviceFamily, ISD::GDInterface *> managedDevices;
 
@@ -487,6 +512,7 @@ class Manager : public QDialog, public Ui::Manager
         std::unique_ptr<Guide> guideProcess;
         std::unique_ptr<Align> alignProcess;
         std::unique_ptr<Mount> mountProcess;
+        std::unique_ptr<Analyze> analyzeProcess;
         std::unique_ptr<Scheduler> schedulerProcess;
         std::unique_ptr<Observatory> observatoryProcess;
         std::unique_ptr<Dome> domeProcess;
@@ -505,6 +531,9 @@ class Manager : public QDialog, public Ui::Manager
 
         CommunicationStatus m_ekosStatus { Ekos::Idle };
         CommunicationStatus m_indiStatus { Ekos::Idle };
+        // Settle is used to know once all properties from all devices have been defined
+        // There is no way to know this for sure so we use a debounace mechanism.
+        CommunicationStatus m_settleStatus { Ekos::Idle };
 
         std::unique_ptr<QStandardItemModel> profileModel;
         QList<std::shared_ptr<ProfileInfo>> profiles;
@@ -522,6 +551,7 @@ class Manager : public QDialog, public Ui::Manager
         QTime overallCountDown;
         QTime sequenceCountDown;
         QTimer countdownTimer;
+        QTimer settleTimer;
         QProgressIndicator *capturePI { nullptr };
         // Preview Frame
         std::unique_ptr<FITSView> summaryPreview;
@@ -543,6 +573,9 @@ class Manager : public QDialog, public Ui::Manager
         // Logs
         QPointer<OpsLogs> opsLogs;
 
+        // E.g. Setup, Scheduler, and Analyze.
+        int numPermanentTabs { 0 };
+
         friend class EkosLive::Client;
         friend class EkosLive::Message;
         friend class EkosLive::Media;
