@@ -43,9 +43,9 @@ FITSLabel::FITSLabel(FITSView *view, QWidget *parent) : QLabel(parent)
 
 void FITSLabel::setSize(double w, double h)
 {
-    width  = w;
-    height = h;
-    size   = w * h;
+    m_Width  = w;
+    m_Height = h;
+    m_Size   = w * h;
 }
 
 bool FITSLabel::getMouseButtonDown()
@@ -99,8 +99,8 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
     x = round(e->x() / scale);
     y = round(e->y() / scale);
 
-    x = KSUtils::clamp(x, 1.0, width);
-    y = KSUtils::clamp(y, 1.0, height);
+    x = KSUtils::clamp(x, 1.0, m_Width);
+    y = KSUtils::clamp(y, 1.0, m_Height);
 
     emit newStatus(QString("X:%1 Y:%2").arg(static_cast<int>(x)).arg(static_cast<int>(y)), FITS_POSITION);
 
@@ -108,7 +108,7 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
     x -= 1;
     y -= 1;
 
-    int index = y * width + x;
+    int index = y * m_Width + x;
     QString stringValue;
 
     switch (view_data->getStatistics().dataType)
@@ -154,19 +154,19 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
 
     if (view_data->hasWCS() && view->getCursorMode() != FITSView::selectCursor)
     {
-        int index = x + y * width;
+        int index = x + y * m_Width;
 
         FITSImage::wcs_point *wcs_coord = view_data->getWCSCoord();
 
         if (wcs_coord)
         {
-            if (index > size)
+            if (index > m_Size)
                 return;
 
-            ra.setD(wcs_coord[index].ra);
-            dec.setD(wcs_coord[index].dec);
+            m_RA.setD(wcs_coord[index].ra);
+            m_DE.setD(wcs_coord[index].dec);
 
-            emit newStatus(QString("%1 , %2").arg(ra.toHMSString(), dec.toDMSString()), FITS_WCS);
+            emit newStatus(QString("%1 , %2").arg(m_RA.toHMSString(), m_DE.toDMSString()), FITS_WCS);
         }
 
         bool objFound = false;
@@ -225,9 +225,9 @@ void FITSLabel::mousePressEvent(QMouseEvent *e)
                 x = round(e->x() / scale);
                 y = round(e->y() / scale);
 
-                x         = KSUtils::clamp(x, 1.0, width);
-                y         = KSUtils::clamp(y, 1.0, height);
-                int index = x + y * width;
+                x         = KSUtils::clamp(x, 1.0, m_Width);
+                y         = KSUtils::clamp(y, 1.0, m_Height);
+                int index = x + y * m_Width;
                 if (KMessageBox::Continue == KMessageBox::warningContinueCancel(
                             nullptr,
                             "Slewing to Coordinates: \nRA: " + dms(wcs_coord[index].ra).toHMSString() +
@@ -249,8 +249,8 @@ void FITSLabel::mousePressEvent(QMouseEvent *e)
     x = round(e->x() / scale);
     y = round(e->y() / scale);
 
-    x = KSUtils::clamp(x, 1.0, width);
-    y = KSUtils::clamp(y, 1.0, height);
+    x = KSUtils::clamp(x, 1.0, m_Width);
+    y = KSUtils::clamp(y, 1.0, m_Height);
 
 #ifdef HAVE_INDI
     FITSData *view_data = view->getImageData();
@@ -308,8 +308,8 @@ void FITSLabel::mouseDoubleClickEvent(QMouseEvent *e)
     x = round(e->x() / (view->getCurrentZoom() / ZOOM_DEFAULT));
     y = round(e->y() / (view->getCurrentZoom() / ZOOM_DEFAULT));
 
-    x = KSUtils::clamp(x, 1.0, width);
-    y = KSUtils::clamp(y, 1.0, height);
+    x = KSUtils::clamp(x, 1.0, m_Width);
+    y = KSUtils::clamp(y, 1.0, m_Height);
 
     emit markerSelected(x, y);
 
