@@ -17,7 +17,8 @@
 #include "fitstab.h"
 
 #include "fitsdata.h"
-#include "fitshistogram.h"
+#include "fitshistogrameditor.h"
+#include "fitshistogramcommand.h"
 #include "fitsview.h"
 #include "fitsviewer.h"
 #include "ksnotification.h"
@@ -49,7 +50,11 @@ FITSTab::FITSTab(FITSViewer *parent) : QWidget(parent)
 
     statWidget = new QDialog(this);
     fitsHeaderDialog = new QDialog(this);
-    histogram = new FITSHistogram(this);
+    m_HistogramEditor = new FITSHistogramEditor(this);
+    connect(m_HistogramEditor, &FITSHistogramEditor::newHistogramCommand, [this](FITSHistogramCommand * command)
+    {
+        undoStack->push(command);
+    });
 }
 
 FITSTab::~FITSTab()
@@ -61,7 +66,7 @@ FITSTab::~FITSTab()
 
 void FITSTab::saveUnsaved()
 {
-    if (undoStack->isClean() || view->getMode() != FITS_NORMAL)
+    if (undoStack->isClean() || m_View->getMode() != FITS_NORMAL)
         return;
 
     QString caption = i18n("Save Changes to FITS?");
@@ -163,13 +168,13 @@ void setupStretchButton(QPushButton *button, const QString &iconName, const QStr
 // Updates all the widgets in the stretch area to display the view's stretch parameters.
 void FITSTab::setStretchUIValues(bool adjustSliders)
 {
-    StretchParams1Channel params = view->getStretchParams().grey_red;
+    StretchParams1Channel params = m_View->getStretchParams().grey_red;
     setSlider(shadowsSlider.get(), shadowsVal.get(), params.shadows, maxShadows, adjustSliders);
     setSlider(midtonesSlider.get(), midtonesVal.get(), params.midtones, maxMidtones, adjustSliders);
     setSlider(highlightsSlider.get(), highlightsVal.get(), params.highlights, maxHighlights, adjustSliders);
 
 
-    bool stretchActive = view->isImageStretched();
+    bool stretchActive = m_View->isImageStretched();
     if (stretchActive)
     {
         stretchButton->setChecked(true);
@@ -182,7 +187,7 @@ void FITSTab::setStretchUIValues(bool adjustSliders)
     }
 
     // Only activate the auto button if stretching is on and auto-stretching is not set.
-    if (stretchActive && !view->getAutoStretch())
+    if (stretchActive && !m_View->getAutoStretch())
     {
         autoButton->setEnabled(true);
         autoButton->setIcon(QIcon::fromTheme("tools-wizard"));
@@ -196,7 +201,7 @@ void FITSTab::setStretchUIValues(bool adjustSliders)
         autoButton->setIconSize(QSize(22, 22));
         autoButton->setToolTip("");
     }
-    autoButton->setChecked(view->getAutoStretch());
+    autoButton->setChecked(m_View->getAutoStretch());
 
     // Disable most of the UI if stretching is not active.
     shadowsSlider->setEnabled(stretchActive);
@@ -213,8 +218,8 @@ void FITSTab::setStretchUIValues(bool adjustSliders)
 // Adjusts the maxShadows value so that we have room to adjust the slider.
 void FITSTab::rescaleShadows()
 {
-    if (!view) return;
-    StretchParams1Channel params = view->getStretchParams().grey_red;
+    if (!m_View) return;
+    StretchParams1Channel params = m_View->getStretchParams().grey_red;
     maxShadows = std::max(0.002f, std::min(1.0f, params.shadows * 2.0f));
     setStretchUIValues(true);
 }
@@ -222,8 +227,8 @@ void FITSTab::rescaleShadows()
 // Adjusts the maxMidtones value so that we have room to adjust the slider.
 void FITSTab::rescaleMidtones()
 {
-    if (!view) return;
-    StretchParams1Channel params = view->getStretchParams().grey_red;
+    if (!m_View) return;
+    StretchParams1Channel params = m_View->getStretchParams().grey_red;
     maxMidtones = std::max(.002f, std::min(1.0f, params.midtones * 2.0f));
     setStretchUIValues(true);
 }
@@ -268,55 +273,55 @@ QHBoxLayout* FITSTab::setupStretchBar()
     connect(stretchButton.get(), &QPushButton::clicked, [ = ]()
     {
         // This will toggle whether we're currently stretching.
-        view->setStretch(!view->isImageStretched());
+        m_View->setStretch(!m_View->isImageStretched());
     });
 
     // Make rough displays for the slider movement.
     connect(shadowsSlider.get(), &QSlider::sliderMoved, [ = ](int value)
     {
-        StretchParams params = view->getStretchParams();
+        StretchParams params = m_View->getStretchParams();
         params.grey_red.shadows = this->maxShadows * value / 10000.0f;
-        view->setPreviewSampling(Options::stretchPreviewSampling());
-        view->setStretchParams(params);
-        view->setPreviewSampling(0);
+        m_View->setPreviewSampling(Options::stretchPreviewSampling());
+        m_View->setStretchParams(params);
+        m_View->setPreviewSampling(0);
     });
     connect(midtonesSlider.get(), &QSlider::sliderMoved, [ = ](int value)
     {
-        StretchParams params = view->getStretchParams();
+        StretchParams params = m_View->getStretchParams();
         params.grey_red.midtones = this->maxMidtones * value / 10000.0f;
-        view->setPreviewSampling(Options::stretchPreviewSampling());
-        view->setStretchParams(params);
-        view->setPreviewSampling(0);
+        m_View->setPreviewSampling(Options::stretchPreviewSampling());
+        m_View->setStretchParams(params);
+        m_View->setPreviewSampling(0);
     });
     connect(highlightsSlider.get(), &QSlider::sliderMoved, [ = ](int value)
     {
-        StretchParams params = view->getStretchParams();
+        StretchParams params = m_View->getStretchParams();
         params.grey_red.highlights = this->maxHighlights * value / 10000.0f;
-        view->setPreviewSampling(Options::stretchPreviewSampling());
-        view->setStretchParams(params);
-        view->setPreviewSampling(0);
+        m_View->setPreviewSampling(Options::stretchPreviewSampling());
+        m_View->setStretchParams(params);
+        m_View->setPreviewSampling(0);
     });
 
     // Make a final full-res display when the slider is released.
     connect(shadowsSlider.get(), &QSlider::sliderReleased, [ = ]()
     {
-        if (!view) return;
+        if (!m_View) return;
         rescaleShadows();
-        StretchParams params = view->getStretchParams();
-        view->setStretchParams(params);
+        StretchParams params = m_View->getStretchParams();
+        m_View->setStretchParams(params);
     });
     connect(midtonesSlider.get(), &QSlider::sliderReleased, [ = ]()
     {
-        if (!view) return;
+        if (!m_View) return;
         rescaleMidtones();
-        StretchParams params = view->getStretchParams();
-        view->setStretchParams(params);
+        StretchParams params = m_View->getStretchParams();
+        m_View->setStretchParams(params);
     });
     connect(highlightsSlider.get(), &QSlider::sliderReleased, [ = ]()
     {
-        if (!view) return;
-        StretchParams params = view->getStretchParams();
-        view->setStretchParams(params);
+        if (!m_View) return;
+        StretchParams params = m_View->getStretchParams();
+        m_View->setStretchParams(params);
     });
 
     connect(autoButton.get(), &QPushButton::clicked, [ = ]()
@@ -324,8 +329,8 @@ QHBoxLayout* FITSTab::setupStretchBar()
         // If we're not currently using automatic stretch parameters, turn that on.
         // If we're already using automatic parameters, don't do anything.
         // User can just move the sliders to take manual control.
-        if (!view->getAutoStretch())
-            view->setAutoStretchParams();
+        if (!m_View->getAutoStretch())
+            m_View->setAutoStretchParams();
         else
             KMessageBox::information(this, "You are already using automatic stretching. To manually stretch, drag a slider.");
         setStretchUIValues(false);
@@ -333,7 +338,7 @@ QHBoxLayout* FITSTab::setupStretchBar()
 
     // This is mostly useful right at the start, when the image is displayed without any user interaction.
     // Check for slider-in-use, as we don't wont to rescale while the user is active.
-    connect(view.get(), &FITSView::newStatus, [ = ](const QString & ignored)
+    connect(m_View.get(), &FITSView::newStatus, [ = ](const QString & ignored)
     {
         Q_UNUSED(ignored)
         bool slidersInUse = shadowsSlider->isSliderDown() || midtonesSlider->isSliderDown() ||
@@ -351,10 +356,10 @@ QHBoxLayout* FITSTab::setupStretchBar()
 
 bool FITSTab::setupView(FITSMode mode, FITSScale filter)
 {
-    if (view.get() == nullptr)
+    if (m_View.get() == nullptr)
     {
-        view.reset(new FITSView(this, mode, filter));
-        view->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+        m_View.reset(new FITSView(this, mode, filter));
+        m_View->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
         QVBoxLayout *vlayout = new QVBoxLayout();
 
         fitsSplitter = new QSplitter(Qt::Horizontal, this);
@@ -377,7 +382,7 @@ bool FITSTab::setupView(FITSMode mode, FITSScale filter)
 
         fitsTools->addItem(statWidget, i18n("Statistics"));
 
-        fitsTools->addItem(histogram, i18n("Histogram"));
+        fitsTools->addItem(m_HistogramEditor, i18n("Histogram"));
 
         header.setupUi(fitsHeaderDialog);
         fitsTools->addItem(fitsHeaderDialog, i18n("FITS Header"));
@@ -398,23 +403,23 @@ bool FITSTab::setupView(FITSMode mode, FITSScale filter)
         scrollFitsPanel->setWidget(fitsTools);
 
         fitsSplitter->addWidget(scrollFitsPanel);
-        fitsSplitter->addWidget(view.get());
+        fitsSplitter->addWidget(m_View.get());
 
 
         //This code allows the fitsTools to start in a closed state
-        fitsSplitter->setSizes(QList<int>() << 0 << view->width() );
+        fitsSplitter->setSizes(QList<int>() << 0 << m_View->width() );
 
         vlayout->addWidget(fitsSplitter);
         vlayout->addLayout(setupStretchBar());
 
-        connect(fitsSplitter, &QSplitter::splitterMoved, histogram, &FITSHistogram::resizePlot);
+        connect(fitsSplitter, &QSplitter::splitterMoved, m_HistogramEditor, &FITSHistogramEditor::resizePlot);
 
         setLayout(vlayout);
-        connect(view.get(), &FITSView::newStatus, this, &FITSTab::newStatus);
-        connect(view.get(), &FITSView::debayerToggled, this, &FITSTab::debayerToggled);
+        connect(m_View.get(), &FITSView::newStatus, this, &FITSTab::newStatus);
+        connect(m_View.get(), &FITSView::debayerToggled, this, &FITSTab::debayerToggled);
 
         // On Failure to load
-        connect(view.get(), &FITSView::failed, this, &FITSTab::failed);
+        connect(m_View.get(), &FITSView::failed, this, &FITSTab::failed);
 
         return true;
     }
@@ -433,7 +438,7 @@ void FITSTab::loadFile(const QUrl &imageURL, FITSMode mode, FITSScale filter, bo
     {
 
         // On Success loading image
-        connect(view.get(), &FITSView::loaded, [&]()
+        connect(m_View.get(), &FITSView::loaded, [&]()
         {
             processData();
             emit loaded();
@@ -445,9 +450,9 @@ void FITSTab::loadFile(const QUrl &imageURL, FITSMode mode, FITSScale filter, bo
 
     currentURL = imageURL;
 
-    view->setFilter(filter);
+    m_View->setFilter(filter);
 
-    view->loadFile(imageURL.toLocalFile(), silent);
+    m_View->loadFile(imageURL.toLocalFile(), silent);
 }
 
 bool FITSTab::shouldComputeHFR() const
@@ -456,33 +461,28 @@ bool FITSTab::shouldComputeHFR() const
         return true;
     if (!Options::autoHFR())
         return false;
-    return (view != nullptr) && (view->getMode() == FITS_NORMAL);
+    return (m_View != nullptr) && (m_View->getMode() == FITS_NORMAL);
 }
 
 void FITSTab::processData()
 {
-    FITSData *image_data = view->getImageData();
-    histogram->reset();
-    image_data->setHistogram(histogram);
+    const QSharedPointer<FITSData> imageData = m_View->imageData();
+
+    m_HistogramEditor->setImageData(imageData);
 
     // Only construct histogram if it is actually visible
     // Otherwise wait until histogram is needed before creating it.
-    if (fitsSplitter->sizes().at(0) != 0)
-    {
-        histogram->constructHistogram();
-    }
+    //    if (fitsSplitter->sizes().at(0) != 0 && !imageData->isHistogramConstructed() &&
+    //            !Options::nonLinearHistogram())
+    //    {
+    //        imageData->constructHistogram();
+    //    }
 
     if (shouldComputeHFR())
     {
-        view->searchStars();
-        qCDebug(KSTARS_FITS) << "FITS HFR:" << image_data->getHFR();
+        m_View->searchStars();
+        qCDebug(KSTARS_FITS) << "FITS HFR:" << imageData->getHFR();
     }
-    // This could both compute the HFRs and setup the graphics, however,
-    // if shouldComputeHFR() above is true, then that will compute the HFRs
-    // and this would notice that and just setup graphics. They are separated
-    // for the case where the graphics is not desired.
-    if (viewer->isStarsMarked())
-        view->toggleStars(true);
 
     evaluateStats();
 
@@ -491,18 +491,30 @@ void FITSTab::processData()
     // Don't add it to the list if it is already there
     if (recentImages->findItems(currentURL.toLocalFile(), Qt::MatchExactly).count() == 0)
     {
-        if(!image_data->isTempFile()) //Don't add it to the list if it is a preview
+        //Don't add it to the list if it is a preview
+        if(!imageData->filename().startsWith(QDir::tempPath()))
         {
             disconnect(recentImages, &QListWidget::currentRowChanged, this,
                        &FITSTab::selectRecentFITS);
-            recentImages->addItem(image_data->filename());
+            recentImages->addItem(imageData->filename());
             recentImages->setCurrentRow(recentImages->count() - 1);
             connect(recentImages, &QListWidget::currentRowChanged,  this,
                     &FITSTab::selectRecentFITS);
         }
     }
 
-    view->updateFrame();
+    //     This could both compute the HFRs and setup the graphics, however,
+    //     if shouldComputeHFR() above is true, then that will compute the HFRs
+    //     and this would notice that and just setup graphics. They are separated
+    //     for the case where the graphics is not desired.
+    if (viewer->isStarsMarked())
+    {
+        m_View->toggleStars(true);
+        m_View->updateFrame();
+    }
+
+    //    if (Options::nonLinearHistogram())
+    //        m_HistogramEditor->createNonLinearHistogram();
 }
 
 bool FITSTab::loadData(const QSharedPointer<FITSData> &data, FITSMode mode, FITSScale filter)
@@ -512,9 +524,15 @@ bool FITSTab::loadData(const QSharedPointer<FITSData> &data, FITSMode mode, FITS
     // Empty URL
     currentURL = QUrl();
 
-    view->setFilter(filter);
+    if (viewer->isStarsMarked())
+    {
+        m_View->toggleStars(true);
+        //view->updateFrame();
+    }
 
-    if (!view->loadData(data))
+    m_View->setFilter(filter);
+
+    if (!m_View->loadData(data))
     {
         // On Failure to load
         // connect(view.get(), &FITSView::failed, this, &FITSTab::failed);
@@ -542,39 +560,45 @@ void FITSTab::modifyFITSState(bool clean, const QUrl &imageURL)
 
 bool FITSTab::saveImage(const QString &filename)
 {
-    return view->saveImage(filename);
+    return m_View->saveImage(filename);
 }
 
 void FITSTab::copyFITS()
 {
-    QApplication::clipboard()->setImage(view->getDisplayImage());
+    QApplication::clipboard()->setImage(m_View->getDisplayImage());
 }
 
 void FITSTab::histoFITS()
 {
-    if (!histogram->isConstructed())
-    {
-        histogram->constructHistogram();
-        evaluateStats();
-    }
+    //    if (Options::nonLinearHistogram())
+    //    {
+    //        m_HistogramEditor->createNonLinearHistogram();
+    //        evaluateStats();
+    //    }
+    //    if (!m_View->imageData()->isHistogramConstructed())
+    //    {
+    //        m_View->imageData()->constructHistogram();
+    //        evaluateStats();
+    //    }
 
     fitsTools->setCurrentIndex(1);
-    if(view->width() > 200)
-        fitsSplitter->setSizes(QList<int>() << 200 << view->width() - 200);
+    if(m_View->width() > 200)
+        fitsSplitter->setSizes(QList<int>() << 200 << m_View->width() - 200);
     else
         fitsSplitter->setSizes(QList<int>() << 50 << 50);
 }
 
 void FITSTab::evaluateStats()
 {
-    FITSData *image_data = view->getImageData();
+    //FITSData *image_data = view->getImageData();
+    const QSharedPointer<FITSData> imageData = m_View->imageData();
 
-    stat.statsTable->item(STAT_WIDTH, 0)->setText(QString::number(image_data->width()));
-    stat.statsTable->item(STAT_HEIGHT, 0)->setText(QString::number(image_data->height()));
-    stat.statsTable->item(STAT_BITPIX, 0)->setText(QString::number(image_data->bpp()));
-    stat.statsTable->item(STAT_HFR, 0)->setText(QString::number(image_data->getHFR(), 'f', 3));
+    stat.statsTable->item(STAT_WIDTH, 0)->setText(QString::number(imageData->width()));
+    stat.statsTable->item(STAT_HEIGHT, 0)->setText(QString::number(imageData->height()));
+    stat.statsTable->item(STAT_BITPIX, 0)->setText(QString::number(imageData->bpp()));
+    stat.statsTable->item(STAT_HFR, 0)->setText(QString::number(imageData->getHFR(), 'f', 3));
 
-    if (image_data->channels() == 1)
+    if (imageData->channels() == 1)
     {
         for (int i = STAT_MIN; i <= STAT_STDDEV; i++)
         {
@@ -599,36 +623,36 @@ void FITSTab::evaluateStats()
         stat.statsTable->showColumn(2);
     }
 
-    if (image_data->getMedian() == 0.0 && !histogram->isConstructed())
-        histogram->constructHistogram();
+    if (!Options::nonLinearHistogram() && !imageData->isHistogramConstructed())
+        imageData->constructHistogram();
 
-    for (int i = 0; i < image_data->channels(); i++)
+    for (int i = 0; i < imageData->channels(); i++)
     {
-        stat.statsTable->item(STAT_MIN, i)->setText(QString::number(image_data->getMin(i), 'f', 3));
-        stat.statsTable->item(STAT_MAX, i)->setText(QString::number(image_data->getMax(i), 'f', 3));
-        stat.statsTable->item(STAT_MEAN, i)->setText(QString::number(image_data->getMean(i), 'f', 3));
-        stat.statsTable->item(STAT_MEDIAN, i)->setText(QString::number(image_data->getMedian(i), 'f', 3));
-        stat.statsTable->item(STAT_STDDEV, i)->setText(QString::number(image_data->getStdDev(i), 'f', 3));
+        stat.statsTable->item(STAT_MIN, i)->setText(QString::number(imageData->getMin(i), 'f', 3));
+        stat.statsTable->item(STAT_MAX, i)->setText(QString::number(imageData->getMax(i), 'f', 3));
+        stat.statsTable->item(STAT_MEAN, i)->setText(QString::number(imageData->getMean(i), 'f', 3));
+        stat.statsTable->item(STAT_MEDIAN, i)->setText(QString::number(imageData->getMedian(i), 'f', 3));
+        stat.statsTable->item(STAT_STDDEV, i)->setText(QString::number(imageData->getStdDev(i), 'f', 3));
     }
 }
 
 void FITSTab::statFITS()
 {
     fitsTools->setCurrentIndex(0);
-    if(view->width() > 200)
-        fitsSplitter->setSizes(QList<int>() << 200 << view->width() - 200);
+    if(m_View->width() > 200)
+        fitsSplitter->setSizes(QList<int>() << 200 << m_View->width() - 200);
     else
         fitsSplitter->setSizes(QList<int>() << 50 << 50);
 }
 
 void FITSTab::loadFITSHeader()
 {
-    FITSData *image_data = view->getImageData();
+    const QSharedPointer<FITSData> imageData = m_View->imageData();
 
-    int nkeys = image_data->getRecords().size();
+    int nkeys = imageData->getRecords().size();
     int counter = 0;
     header.tableWidget->setRowCount(nkeys);
-    for (const auto &oneRecord : image_data->getRecords())
+    for (const auto &oneRecord : imageData->getRecords())
     {
         QTableWidgetItem *tempItem = new QTableWidgetItem(oneRecord.key);
         tempItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
@@ -650,8 +674,8 @@ void FITSTab::loadFITSHeader()
 void FITSTab::headerFITS()
 {
     fitsTools->setCurrentIndex(2);
-    if(view->width() > 200)
-        fitsSplitter->setSizes(QList<int>() << 200 << view->width() - 200);
+    if(m_View->width() > 200)
+        fitsSplitter->setSizes(QList<int>() << 200 << m_View->width() - 200);
     else
         fitsSplitter->setSizes(QList<int>() << 50 << 50);
 }
@@ -695,7 +719,7 @@ bool FITSTab::saveFile()
 
         if (!saveImage(localFile))
         {
-            KSNotification::error(i18n("Image save error: %1", view->getImageData()->getLastError()), i18n("Image Save"));
+            KSNotification::error(i18n("Image save error: %1", m_View->getImageData()->getLastError()), i18n("Image Save"));
             return false;
         }
 
@@ -719,29 +743,29 @@ bool FITSTab::saveFileAs()
 
 void FITSTab::ZoomIn()
 {
-    QPoint oldCenter = view->getImagePoint(view->viewport()->rect().center());
-    view->ZoomIn();
-    view->cleanUpZoom(oldCenter);
+    QPoint oldCenter = m_View->getImagePoint(m_View->viewport()->rect().center());
+    m_View->ZoomIn();
+    m_View->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::ZoomOut()
 {
-    QPoint oldCenter = view->getImagePoint(view->viewport()->rect().center());
-    view->ZoomOut();
-    view->cleanUpZoom(oldCenter);
+    QPoint oldCenter = m_View->getImagePoint(m_View->viewport()->rect().center());
+    m_View->ZoomOut();
+    m_View->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::ZoomDefault()
 {
-    QPoint oldCenter = view->getImagePoint(view->viewport()->rect().center());
-    view->ZoomDefault();
-    view->cleanUpZoom(oldCenter);
+    QPoint oldCenter = m_View->getImagePoint(m_View->viewport()->rect().center());
+    m_View->ZoomDefault();
+    m_View->cleanUpZoom(oldCenter);
 }
 
 void FITSTab::tabPositionUpdated()
 {
     undoStack->setActive(true);
-    emit newStatus(QString("%1%").arg(view->getCurrentZoom()), FITS_ZOOM);
-    emit newStatus(QString("%1x%2").arg(view->getImageData()->width()).arg(view->getImageData()->height()),
+    emit newStatus(QString("%1%").arg(m_View->getCurrentZoom()), FITS_ZOOM);
+    emit newStatus(QString("%1x%2").arg(m_View->getImageData()->width()).arg(m_View->getImageData()->height()),
                    FITS_RESOLUTION);
 }
