@@ -86,11 +86,11 @@ void ComputeGBStretchParams(const StretchParams &newParams, StretchParams* param
 // In that case, it will use an identity stretch.
 void FITSView::doStretch(QImage *outputImage)
 {
-    if (outputImage->isNull() || imageData.isNull())
+    if (outputImage->isNull() || m_ImageData.isNull())
         return;
-    Stretch stretch(static_cast<int>(imageData->width()),
-                    static_cast<int>(imageData->height()),
-                    imageData->channels(), imageData->getStatistics().dataType);
+    Stretch stretch(static_cast<int>(m_ImageData->width()),
+                    static_cast<int>(m_ImageData->height()),
+                    m_ImageData->channels(), m_ImageData->dataType());
 
     StretchParams tempParams;
     if (!stretchImage)
@@ -98,7 +98,7 @@ void FITSView::doStretch(QImage *outputImage)
     else if (autoStretch)
     {
         // Compute new auto-stretch params.
-        stretchParams = stretch.computeParams(imageData->getImageBuffer());
+        stretchParams = stretch.computeParams(m_ImageData->getImageBuffer());
         tempParams = stretchParams;
     }
     else
@@ -106,13 +106,13 @@ void FITSView::doStretch(QImage *outputImage)
         tempParams = stretchParams;
 
     stretch.setParams(tempParams);
-    stretch.run(imageData->getImageBuffer(), outputImage, m_PreviewSampling);
+    stretch.run(m_ImageData->getImageBuffer(), outputImage, m_PreviewSampling);
 }
 
 // Store stretch parameters, and turn on stretching if it isn't already on.
 void FITSView::setStretchParams(const StretchParams &params)
 {
-    if (imageData->channels() == 3)
+    if (m_ImageData->channels() == 3)
         ComputeGBStretchParams(params, &stretchParams);
 
     stretchParams.grey_red = params.grey_red;
@@ -123,8 +123,8 @@ void FITSView::setStretchParams(const StretchParams &params)
     autoStretch = false;
     stretchImage = true;
 
-    if (image_frame != nullptr && rescale(ZOOM_KEEP_LEVEL))
-        updateFrame();
+    if (m_ImageFrame && rescale(ZOOM_KEEP_LEVEL))
+        updateFrame(true);
 }
 
 // Turn on or off stretching, and if on, use whatever parameters are currently stored.
@@ -133,8 +133,8 @@ void FITSView::setStretch(bool onOff)
     if (stretchImage != onOff)
     {
         stretchImage = onOff;
-        if (image_frame != nullptr && rescale(ZOOM_KEEP_LEVEL))
-            updateFrame();
+        if (m_ImageFrame && rescale(ZOOM_KEEP_LEVEL))
+            updateFrame(true);
     }
 }
 
@@ -143,11 +143,11 @@ void FITSView::setAutoStretchParams()
 {
     stretchImage = true;
     autoStretch = true;
-    if (image_frame != nullptr && rescale(ZOOM_KEEP_LEVEL))
-        updateFrame();
+    if (m_ImageFrame && rescale(ZOOM_KEEP_LEVEL))
+        updateFrame(true);
 }
 
-FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) : QScrollArea(parent), zoomFactor(1.2)
+FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) : QScrollArea(parent), m_ZoomFactor(1.2)
 {
     // stretchImage is whether to stretch or not--the stretch may or may not use automatically generated parameters.
     // The user may enter his/her own.
@@ -187,7 +187,6 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) :
 
     grabGesture(Qt::PinchGesture);
 
-    image_frame.reset(new FITSLabel(this));
     filter = filterType;
     mode   = fitsMode;
 
@@ -198,14 +197,33 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) :
 
     setBaseSize(740, 530);
 
-    connect(image_frame.get(), SIGNAL(newStatus(QString, FITSBar)), this, SIGNAL(newStatus(QString, FITSBar)));
-    connect(image_frame.get(), SIGNAL(pointSelected(int, int)), this, SLOT(processPointSelection(int, int)));
-    connect(image_frame.get(), SIGNAL(markerSelected(int, int)), this, SLOT(processMarkerSelection(int, int)));
+    m_ImageFrame = new FITSLabel(this);
+    m_ImageFrame->setMouseTracking(true);
+    connect(m_ImageFrame, SIGNAL(newStatus(QString, FITSBar)), this, SIGNAL(newStatus(QString, FITSBar)));
+    connect(m_ImageFrame, SIGNAL(pointSelected(int, int)), this, SLOT(processPointSelection(int, int)));
+    connect(m_ImageFrame, SIGNAL(markerSelected(int, int)), this, SLOT(processMarkerSelection(int, int)));
+
     connect(&wcsWatcher, SIGNAL(finished()), this, SLOT(syncWCSState()));
 
+    m_UpdateFrameTimer.setInterval(50);
+    m_UpdateFrameTimer.setSingleShot(true);
+    connect(&m_UpdateFrameTimer, &QTimer::timeout, [this]()
+    {
+        if (toggleStretchAction)
+            toggleStretchAction->setChecked(stretchImage);
+
+        // We employ two schemes for managing the image and its overlays, depending on the size of the image
+        // and whether we need to therefore conserve memory. The small-image strategy explicitly scales up
+        // the image, and writes overlays on the scaled pixmap. The large-image strategy uses a pixmap that's
+        // the size of the image itself, never scaling that up.
+        if (isLargeImage())
+            updateFrameLargeImage();
+        else
+            updateFrameSmallImage();
+    });
+
     connect(&fitsWatcher, &QFutureWatcher<bool>::finished, this, &FITSView::loadInFrame);
 
-    image_frame->setMouseTracking(true);
     setCursorMode(
         selectCursor); //This is the default mode because the Focus and Align FitsViews should not be in dragMouse mode
 
@@ -213,7 +231,7 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) :
     noImage.load(":/images/noimage.png");
     noImageLabel->setPixmap(noImage);
     noImageLabel->setAlignment(Qt::AlignCenter);
-    this->setWidget(noImageLabel);
+    setWidget(noImageLabel);
 
     redScopePixmap = QPixmap(":/icons/center_telescope_red.svg").scaled(32, 32, Qt::KeepAspectRatio, Qt::FastTransformation);
     magentaScopePixmap = QPixmap(":/icons/center_telescope_magenta.svg").scaled(32, 32, Qt::KeepAspectRatio,
@@ -236,7 +254,7 @@ void FITSView::updateMouseCursor()
     {
         if (horizontalScrollBar()->maximum() > 0 || verticalScrollBar()->maximum() > 0)
         {
-            if (!image_frame->getMouseButtonDown())
+            if (!m_ImageFrame->getMouseButtonDown())
                 viewport()->setCursor(Qt::PointingHandCursor);
             else
                 viewport()->setCursor(Qt::ClosedHandCursor);
@@ -273,9 +291,9 @@ void FITSView::setCursorMode(CursorMode mode)
 
     if (mode == scopeCursor && imageHasWCS())
     {
-        if (imageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
+        if (m_ImageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
         {
-            QFuture<bool> future = QtConcurrent::run(imageData.data(), &FITSData::loadWCS, true);
+            QFuture<bool> future = QtConcurrent::run(m_ImageData.data(), &FITSData::loadWCS, true);
             wcsWatcher.setFuture(future);
         }
     }
@@ -283,7 +301,7 @@ void FITSView::setCursorMode(CursorMode mode)
 
 void FITSView::resizeEvent(QResizeEvent * event)
 {
-    if ((imageData == nullptr) && noImageLabel != nullptr)
+    if (m_ImageData == nullptr && noImageLabel != nullptr)
     {
         noImageLabel->setPixmap(
             noImage.scaled(width() - 20, height() - 20, Qt::KeepAspectRatio, Qt::FastTransformation));
@@ -304,10 +322,10 @@ void FITSView::loadFile(const QString &inFilename, bool silent)
     bool setBayerParams = false;
 
     BayerParams param;
-    if ((imageData != nullptr) && imageData->hasDebayer())
+    if ((m_ImageData != nullptr) && m_ImageData->hasDebayer())
     {
         setBayerParams = true;
-        imageData->getBayerParams(&param);
+        m_ImageData->getBayerParams(&param);
     }
 
     // In case image is still loading, wait until it is done.
@@ -315,20 +333,35 @@ void FITSView::loadFile(const QString &inFilename, bool silent)
     // In case loadWCS is still running for previous image data, let's wait until it's over
     wcsWatcher.waitForFinished();
 
-    //    delete imageData;
-    //    imageData = nullptr;
+    //    delete m_ImageData;
+    //    m_ImageData = nullptr;
 
     filterStack.clear();
     filterStack.push(FITS_NONE);
     if (filter != FITS_NONE)
         filterStack.push(filter);
 
-    imageData.reset(new FITSData(mode), &QObject::deleteLater);
+    m_ImageData.reset(new FITSData(mode), &QObject::deleteLater);
 
     if (setBayerParams)
-        imageData->setBayerParams(&param);
+        m_ImageData->setBayerParams(&param);
 
-    fitsWatcher.setFuture(imageData->loadFromFile(inFilename, silent));
+    fitsWatcher.setFuture(m_ImageData->loadFromFile(inFilename, silent));
+}
+
+void FITSView::clearData()
+{
+    if (!noImageLabel)
+    {
+        noImageLabel = new QLabel();
+        noImage.load(":/images/noimage.png");
+        noImageLabel->setPixmap(noImage);
+        noImageLabel->setAlignment(Qt::AlignCenter);
+    }
+
+    setWidget(noImageLabel);
+
+    m_ImageData.clear();
 }
 
 bool FITSView::loadData(const QSharedPointer<FITSData> &data)
@@ -341,19 +374,13 @@ bool FITSView::loadData(const QSharedPointer<FITSData> &data)
     // In case loadWCS is still running for previous image data, let's wait until it's over
     wcsWatcher.waitForFinished();
 
-    //    if (imageData != nullptr)
-    //    {
-    //        delete imageData;
-    //        imageData = nullptr;
-    //    }
-
     filterStack.clear();
     filterStack.push(FITS_NONE);
     if (filter != FITS_NONE)
         filterStack.push(filter);
 
     // Takes control of the objects passed in.
-    imageData = data;
+    m_ImageData = data;
 
     return processData();
 }
@@ -361,21 +388,36 @@ bool FITSView::loadData(const QSharedPointer<FITSData> &data)
 bool FITSView::processData()
 {
     // Set current width and height
-    if (!imageData)
+    if (!m_ImageData)
         return false;
-    currentWidth = imageData->width();
-    currentHeight = imageData->height();
+
+    connect(m_ImageData.get(), &FITSData::dataChanged, [this]()
+    {
+        rescale(ZOOM_KEEP_LEVEL);
+        updateFrame();
+    });
+
+    currentWidth = m_ImageData->width();
+    currentHeight = m_ImageData->height();
 
     int image_width  = currentWidth;
     int image_height = currentHeight;
 
-    image_frame->setSize(image_width, image_height);
+    if (!m_ImageFrame)
+    {
+        m_ImageFrame = new FITSLabel(this);
+        m_ImageFrame->setMouseTracking(true);
+        connect(m_ImageFrame, SIGNAL(newStatus(QString, FITSBar)), this, SIGNAL(newStatus(QString, FITSBar)));
+        connect(m_ImageFrame, SIGNAL(pointSelected(int, int)), this, SLOT(processPointSelection(int, int)));
+        connect(m_ImageFrame, SIGNAL(markerSelected(int, int)), this, SLOT(processMarkerSelection(int, int)));
+    }
+    m_ImageFrame->setSize(image_width, image_height);
 
     // Init the display image
     // JM 2020.01.08: Disabling as proposed by Hy
     //initDisplayImage();
 
-    imageData->applyFilter(filter);
+    m_ImageData->applyFilter(filter);
 
     double availableRAM = 0;
     if (Options::adaptiveSampling() && (availableRAM = KSUtils::getAvailableRAM()) > 0)
@@ -393,7 +435,7 @@ bool FITSView::processData()
         else
             m_AdaptiveSampling = 4;
 
-        m_PreviewSampling *= m_AdaptiveSampling;
+        m_PreviewSampling = m_AdaptiveSampling;
     }
 
     // Rescale to fits window on first load
@@ -422,11 +464,11 @@ bool FITSView::processData()
 
     // Load WCS data now if selected and image contains valid WCS header
     if ((mode == FITS_NORMAL || mode == FITS_ALIGN) &&
-            imageData->hasWCS() && imageData->getWCSState() == FITSData::Idle &&
+            m_ImageData->hasWCS() && m_ImageData->getWCSState() == FITSData::Idle &&
             Options::autoWCS() &&
             !wcsWatcher.isRunning())
     {
-        QFuture<bool> future = QtConcurrent::run(imageData.data(), &FITSData::loadWCS, true);
+        QFuture<bool> future = QtConcurrent::run(m_ImageData.data(), &FITSData::loadWCS, true);
         wcsWatcher.setFuture(future);
     }
     else
@@ -443,7 +485,8 @@ bool FITSView::processData()
         QTimer::singleShot(100, this, SLOT(viewStarProfile()));
     }
 
-    updateFrame();
+    // Fore immediate load of frame for first load.
+    updateFrame(true);
     return true;
 }
 
@@ -452,13 +495,13 @@ void FITSView::loadInFrame()
     // Check if the loading was OK
     if (fitsWatcher.result() == false)
     {
-        m_LastError = imageData->getLastError();
+        m_LastError = m_ImageData->getLastError();
         emit failed();
         return;
     }
 
     // Notify if there is debayer data.
-    emit debayerToggled(imageData->hasDebayer());
+    emit debayerToggled(m_ImageData->hasDebayer());
 
     if (processData())
         emit loaded();
@@ -475,12 +518,12 @@ bool FITSView::saveImage(const QString &newFilename)
         return true;
     }
 
-    return imageData->saveImage(newFilename);
+    return m_ImageData->saveImage(newFilename);
 }
 
 bool FITSView::rescale(FITSZoom type)
 {
-    switch (imageData->getStatistics().dataType)
+    switch (m_ImageData->dataType())
     {
         case TBYTE:
             return rescale<uint8_t>(type);
@@ -522,7 +565,7 @@ void FITSView::enterEvent(QEvent * event)
 {
     Q_UNUSED(event)
 
-    if ((floatingToolBar != nullptr) && (imageData != nullptr))
+    if (floatingToolBar && m_ImageData)
     {
         QPointer<QGraphicsOpacityEffect> eff = new QGraphicsOpacityEffect(this);
         floatingToolBar->setGraphicsEffect(eff);
@@ -539,7 +582,7 @@ void FITSView::leaveEvent(QEvent * event)
 {
     Q_UNUSED(event)
 
-    if ((floatingToolBar != nullptr) && (imageData != nullptr))
+    if (floatingToolBar && m_ImageData)
     {
         QPointer<QGraphicsOpacityEffect> eff = new QGraphicsOpacityEffect(this);
         floatingToolBar->setGraphicsEffect(eff);
@@ -555,14 +598,11 @@ void FITSView::leaveEvent(QEvent * event)
 template <typename T>
 bool FITSView::rescale(FITSZoom type)
 {
-    // JM 2020.01.08: Disabling as proposed by Hy
-    //    if (rawImage.isNull())
-    //        return false;
-
-    if (!imageData)
+    if (!m_ImageData)
         return false;
-    int image_width  = imageData->width();
-    int image_height = imageData->height();
+
+    int image_width  = m_ImageData->width();
+    int image_height = m_ImageData->height();
     currentWidth  = image_width;
     currentHeight = image_height;
 
@@ -616,18 +656,20 @@ bool FITSView::rescale(FITSZoom type)
     }
 
     initDisplayImage();
-    image_frame->setScaledContents(true);
+    m_ImageFrame->setScaledContents(true);
     doStretch(&rawImage);
-    setWidget(image_frame.get());
+    setWidget(m_ImageFrame);
 
     // This is needed by fitstab, even if the zoom doesn't change, to change the stretch UI.
     emit newStatus(QString("%1%").arg(currentZoom), FITS_ZOOM);
-
     return true;
 }
 
 void FITSView::ZoomIn()
 {
+    if (!m_ImageData)
+        return;
+
     if (currentZoom >= ZOOM_DEFAULT && Options::limitedResourcesMode())
     {
         emit newStatus(i18n("Cannot zoom in further due to active limited resources mode."), FITS_MESSAGE);
@@ -646,19 +688,21 @@ void FITSView::ZoomIn()
         emit actionUpdated("view_zoom_in", false);
     }
 
-    if (!imageData) return;
-    currentWidth  = imageData->width() * (currentZoom / ZOOM_DEFAULT);
-    currentHeight = imageData->height() * (currentZoom / ZOOM_DEFAULT);
+    currentWidth  = m_ImageData->width() * (currentZoom / ZOOM_DEFAULT);
+    currentHeight = m_ImageData->height() * (currentZoom / ZOOM_DEFAULT);
 
     cleanUpZoom();
 
-    updateFrame();
+    updateFrame(true);
 
     emit newStatus(QString("%1%").arg(currentZoom), FITS_ZOOM);
 }
 
 void FITSView::ZoomOut()
 {
+    if (!m_ImageData)
+        return;
+
     if (currentZoom <= ZOOM_DEFAULT)
         currentZoom -= ZOOM_LOW_INCR;
     else
@@ -672,23 +716,25 @@ void FITSView::ZoomOut()
 
     emit actionUpdated("view_zoom_in", true);
 
-    if (!imageData) return;
-    currentWidth  = imageData->width() * (currentZoom / ZOOM_DEFAULT);
-    currentHeight = imageData->height() * (currentZoom / ZOOM_DEFAULT);
+    currentWidth  = m_ImageData->width() * (currentZoom / ZOOM_DEFAULT);
+    currentHeight = m_ImageData->height() * (currentZoom / ZOOM_DEFAULT);
 
     cleanUpZoom();
 
-    updateFrame();
+    updateFrame(true);
 
     emit newStatus(QString("%1%").arg(currentZoom), FITS_ZOOM);
 }
 
 void FITSView::ZoomToFit()
 {
+    if (!m_ImageData)
+        return;
+
     if (rawImage.isNull() == false)
     {
         rescale(ZOOM_FIT_WINDOW);
-        updateFrame();
+        updateFrame(true);
     }
 }
 
@@ -700,8 +746,8 @@ void FITSView::setStarFilterRange(float const innerRadius, float const outerRadi
 
 int FITSView::filterStars()
 {
-    return starFilter.used() ? imageData->filterStars(starFilter.innerRadius,
-            starFilter.outerRadius) : imageData->getStarCenters().count();
+    return starFilter.used() ? m_ImageData->filterStars(starFilter.innerRadius,
+            starFilter.outerRadius) : m_ImageData->getStarCenters().count();
 }
 
 // isImageLarge() returns whether we use the large-image rendering strategy or the small-image strategy.
@@ -719,7 +765,7 @@ bool FITSView::isLargeImage()
 // and get scale returns the ratio of that pixmap size to the image size.
 double FITSView::getScale()
 {
-    return isLargeImage() ? 1.0 : currentZoom / ZOOM_DEFAULT;
+    return (isLargeImage() ? 1.0 : currentZoom / ZOOM_DEFAULT) / m_PreviewSampling;
 }
 
 // scaleSize() is only used with the large-image rendering strategy. It may increase the line
@@ -729,22 +775,31 @@ double FITSView::scaleSize(double size)
 {
     if (!isLargeImage())
         return size;
-    return currentZoom > 100.0 ? size : std::round(size * 100.0 / currentZoom);
+    return (currentZoom > 100.0 ? size : std::round(size * 100.0 / currentZoom)) / m_PreviewSampling;
 }
 
-void FITSView::updateFrame()
+void FITSView::updateFrame(bool now)
 {
-    if (toggleStretchAction)
-        toggleStretchAction->setChecked(stretchImage);
+    // JM 2021-03-13: This timer is used to throttle updateFrame calls to improve performance
+    // If after 250ms no further update frames are called, then the actual update is triggered.
+    // JM 2021-03-16: When stretching in progress, immediately execute so that the user see the changes
+    // in real time
+    if (now)
+    {
+        if (toggleStretchAction)
+            toggleStretchAction->setChecked(stretchImage);
 
-    // We employ two schemes for managing the image and its overlays, depending on the size of the image
-    // and whether we need to therefore conserve memory. The small-image strategy explicitly scales up
-    // the image, and writes overlays on the scaled pixmap. The large-image strategy uses a pixmap that's
-    // the size of the image itself, never scaling that up.
-    if (isLargeImage())
-        updateFrameLargeImage();
+        // We employ two schemes for managing the image and its overlays, depending on the size of the image
+        // and whether we need to therefore conserve memory. The small-image strategy explicitly scales up
+        // the image, and writes overlays on the scaled pixmap. The large-image strategy uses a pixmap that's
+        // the size of the image itself, never scaling that up.
+        if (isLargeImage())
+            updateFrameLargeImage();
+        else
+            updateFrameSmallImage();
+    }
     else
-        updateFrameSmallImage();
+        m_UpdateFrameTimer.start();
 }
 
 
@@ -760,14 +815,10 @@ void FITSView::updateFrameLargeImage()
     font.setPixelSize(scaleSize(FONT_SIZE));
     painter.setFont(font);
 
-    if (m_PreviewSampling == 1)
-    {
-        drawOverlay(&painter, 1.0);
-        drawStarFilter(&painter, 1.0);
-    }
-    image_frame->setPixmap(displayPixmap);
-
-    image_frame->resize(((m_PreviewSampling * currentZoom) / 100.0) * image_frame->pixmap()->size());
+    drawOverlay(&painter, 1.0 / m_PreviewSampling);
+    drawStarFilter(&painter, 1.0 / m_PreviewSampling);
+    m_ImageFrame->setPixmap(displayPixmap);
+    m_ImageFrame->resize(((m_PreviewSampling * currentZoom) / 100.0) * displayPixmap.size());
 }
 
 void FITSView::updateFrameSmallImage()
@@ -778,21 +829,21 @@ void FITSView::updateFrameSmallImage()
 
     QPainter painter(&displayPixmap);
 
-    if (m_PreviewSampling == 1)
-    {
-        drawOverlay(&painter, currentZoom / ZOOM_DEFAULT);
-        drawStarFilter(&painter, currentZoom / ZOOM_DEFAULT);
-    }
-    image_frame->setPixmap(displayPixmap);
-    image_frame->resize(currentWidth, currentHeight);
+    //    if (m_PreviewSampling == 1)
+    //    {
+    drawOverlay(&painter, currentZoom / ZOOM_DEFAULT);
+    drawStarFilter(&painter, currentZoom / ZOOM_DEFAULT);
+    //}
+    m_ImageFrame->setPixmap(displayPixmap);
+    m_ImageFrame->resize(currentWidth, currentHeight);
 }
 
 void FITSView::drawStarFilter(QPainter *painter, double scale)
 {
     if (!starFilter.used())
         return;
-    const double w = imageData->width() * scale;
-    const double h = imageData->height() * scale;
+    const double w = m_ImageData->width() * scale;
+    const double h = m_ImageData->height() * scale;
     double const diagonal = std::sqrt(w * w + h * h) / 2;
     int const innerRadius = std::lround(diagonal * starFilter.innerRadius);
     int const outerRadius = std::lround(diagonal * starFilter.outerRadius);
@@ -867,41 +918,41 @@ void drawClip(T *input_buffer, int num_channels, QPainter *painter, int width, i
 
 void FITSView::drawClipping(QPainter *painter)
 {
-    auto input = imageData->getImageBuffer();
-    const int height = imageData->height();
-    const int width = imageData->width();
+    auto input = m_ImageData->getImageBuffer();
+    const int height = m_ImageData->height();
+    const int width = m_ImageData->width();
     constexpr double FLOAT_CLIP = 60000;
     constexpr double SHORT_CLIP = 30000;
     constexpr double USHORT_CLIP = 60000;
     constexpr double BYTE_CLIP = 250;
-    switch (imageData->getStatistics().dataType)
+    switch (m_ImageData->dataType())
     {
         case TBYTE:
-            drawClip(reinterpret_cast<uint8_t const*>(input), imageData->channels(), painter, width, height, BYTE_CLIP,
+            drawClip(reinterpret_cast<uint8_t const*>(input), m_ImageData->channels(), painter, width, height, BYTE_CLIP,
                      scaleSize(1));
             break;
         case TSHORT:
-            drawClip(reinterpret_cast<short const*>(input), imageData->channels(), painter, width, height, SHORT_CLIP,
+            drawClip(reinterpret_cast<short const*>(input), m_ImageData->channels(), painter, width, height, SHORT_CLIP,
                      scaleSize(1));
             break;
         case TUSHORT:
-            drawClip(reinterpret_cast<unsigned short const*>(input), imageData->channels(), painter, width, height, USHORT_CLIP,
+            drawClip(reinterpret_cast<unsigned short const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
                      scaleSize(1));
             break;
         case TLONG:
-            drawClip(reinterpret_cast<long const*>(input), imageData->channels(), painter, width, height, USHORT_CLIP,
+            drawClip(reinterpret_cast<long const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
                      scaleSize(1));
             break;
         case TFLOAT:
-            drawClip(reinterpret_cast<float const*>(input), imageData->channels(), painter, width, height, FLOAT_CLIP,
+            drawClip(reinterpret_cast<float const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
                      scaleSize(1));
             break;
         case TLONGLONG:
-            drawClip(reinterpret_cast<long long const*>(input), imageData->channels(), painter, width, height, USHORT_CLIP,
+            drawClip(reinterpret_cast<long long const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
                      scaleSize(1));
             break;
         case TDOUBLE:
-            drawClip(reinterpret_cast<double const*>(input), imageData->channels(), painter, width, height, FLOAT_CLIP,
+            drawClip(reinterpret_cast<double const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
                      scaleSize(1));
             break;
         default:
@@ -911,14 +962,14 @@ void FITSView::drawClipping(QPainter *painter)
 
 void FITSView::ZoomDefault()
 {
-    if (image_frame != nullptr)
+    if (m_ImageFrame)
     {
         emit actionUpdated("view_zoom_out", true);
         emit actionUpdated("view_zoom_in", true);
 
         currentZoom   = ZOOM_DEFAULT;
-        currentWidth  = imageData->width();
-        currentHeight = imageData->height();
+        currentWidth  = m_ImageData->width();
+        currentHeight = m_ImageData->height();
 
         updateFrame();
 
@@ -1029,7 +1080,7 @@ void FITSView::drawStarCentroid(QPainter * painter, double scale)
 
     painter->setPen(QPen(Qt::red, scaleSize(2)));
 
-    for (auto const &starCenter : imageData->getStarCenters())
+    for (auto const &starCenter : m_ImageData->getStarCenters())
     {
         int const w  = std::round(starCenter->width) * scale;
 
@@ -1122,9 +1173,9 @@ This Method draws a large Crosshair in the center of the image, it is like a set
 
 void FITSView::drawCrosshair(QPainter * painter, double scale)
 {
-    if (!imageData) return;
-    const int image_width = imageData->width();
-    const int image_height = imageData->height();
+    if (!m_ImageData) return;
+    const int image_width = m_ImageData->width();
+    const int image_height = m_ImageData->height();
     const QPointF c   = QPointF((qreal)image_width / 2 * scale, (qreal)image_height / 2 * scale);
     const float midX  = (float)image_width / 2 * scale;
     const float midY  = (float)image_height / 2 * scale;
@@ -1161,8 +1212,8 @@ be in the center of the image.
 
 void FITSView::drawPixelGrid(QPainter * painter, double scale)
 {
-    const float width  = imageData->width() * scale;
-    const float height = imageData->height() * scale;
+    const float width  = m_ImageData->width() * scale;
+    const float height = m_ImageData->height() * scale;
     const float cX     = width / 2;
     const float cY     = height / 2;
     const float deltaX = width / 10;
@@ -1214,15 +1265,15 @@ void FITSView::drawPixelGrid(QPainter * painter, double scale)
 
 bool FITSView::imageHasWCS()
 {
-    if (imageData != nullptr)
-        return imageData->hasWCS();
+    if (m_ImageData != nullptr)
+        return m_ImageData->hasWCS();
     return false;
 }
 
 void FITSView::drawObjectNames(QPainter * painter, double scale)
 {
     painter->setPen(QPen(QColor(KStarsData::Instance()->colorScheme()->colorNamed("FITSObjectLabelColor"))));
-    foreach (FITSSkyObject * listObject, imageData->getSkyObjects())
+    foreach (FITSSkyObject * listObject, m_ImageData->getSkyObjects())
     {
         painter->drawRect(listObject->x() * scale - 5, listObject->y() * scale - 5, 10, 10);
         painter->drawText(listObject->x() * scale + 10, listObject->y() * scale + 10, listObject->skyObject()->name());
@@ -1238,12 +1289,12 @@ to draw gridlines at those specific RA and Dec values.
 
 void FITSView::drawEQGrid(QPainter * painter, double scale)
 {
-    const int image_width = imageData->width();
-    const int image_height = imageData->height();
+    const int image_width = m_ImageData->width();
+    const int image_height = m_ImageData->height();
 
-    if (imageData->hasWCS() && imageData->fullWCS())
+    if (m_ImageData->hasWCS() && m_ImageData->fullWCS())
     {
-        FITSImage::wcs_point * wcs_coord = imageData->getWCSCoord();
+        FITSImage::wcs_point * wcs_coord = m_ImageData->getWCSCoord();
         if (wcs_coord != nullptr)
         {
             const int size      = image_width * image_height;
@@ -1327,7 +1378,7 @@ void FITSView::drawEQGrid(QPainter * painter, double scale)
                 for (double targetDec = minDec; targetDec <= maxDec; targetDec += increment)
                 {
                     SkyPoint pointToGet(target / 15.0, targetDec);
-                    bool inImage = imageData->wcsToPixel(pointToGet, pixelPoint, imagePoint);
+                    bool inImage = m_ImageData->wcsToPixel(pointToGet, pixelPoint, imagePoint);
                     if (inImage)
                     {
                         QPointF pt(pixelPoint.x() * scale, pixelPoint.y() * scale);
@@ -1363,10 +1414,10 @@ void FITSView::drawEQGrid(QPainter * painter, double scale)
                 for (double targetRA = minRA; targetRA <= maxRA; targetRA += increment)
                 {
                     SkyPoint pointToGet(targetRA / 15, targetDec * decConvert);
-                    bool inImage = imageData->wcsToPixel(pointToGet, pixelPoint, imagePoint);
+                    bool inImage = m_ImageData->wcsToPixel(pointToGet, pixelPoint, imagePoint);
                     if (inImage)
                     {
-                        QPointF pt(pixelPoint.x(), pixelPoint.y());
+                        QPointF pt(pixelPoint.x() * scale, pixelPoint.y() * scale);
                         eqGridPoints.append(pt);
                     }
                 }
@@ -1384,7 +1435,7 @@ void FITSView::drawEQGrid(QPainter * painter, double scale)
             //This Section Draws the North Celestial Pole if present
             SkyPoint NCP(0, 90);
 
-            bool NCPtest = imageData->wcsToPixel(NCP, pPoint, imagePoint);
+            bool NCPtest = m_ImageData->wcsToPixel(NCP, pPoint, imagePoint);
             if (NCPtest)
             {
                 bool NCPinImage =
@@ -1401,7 +1452,7 @@ void FITSView::drawEQGrid(QPainter * painter, double scale)
             //This Section Draws the South Celestial Pole if present
             SkyPoint SCP(0, -90);
 
-            bool SCPtest = imageData->wcsToPixel(SCP, pPoint, imagePoint);
+            bool SCPtest = m_ImageData->wcsToPixel(SCP, pPoint, imagePoint);
             if (SCPtest)
             {
                 bool SCPinImage =
@@ -1420,8 +1471,8 @@ void FITSView::drawEQGrid(QPainter * painter, double scale)
 
 bool FITSView::pointIsInImage(QPointF pt, double scale)
 {
-    int image_width = imageData->width();
-    int image_height = imageData->height();
+    int image_width = m_ImageData->width();
+    int image_height = m_ImageData->height();
     return pt.x() < image_width * scale && pt.y() < image_height * scale && pt.x() > 0 && pt.y() > 0;
 }
 
@@ -1434,8 +1485,8 @@ QPointF FITSView::getPointForGridLabel(QPainter *painter, const QString &str, do
     int strWidth = fm.horizontalAdvance(str);
 #endif
     int strHeight = fm.height();
-    int image_width = imageData->width();
-    int image_height = imageData->height();
+    int image_width = m_ImageData->width();
+    int image_height = m_ImageData->height();
 
     //These get the maximum X and Y points in the list that are in the image
     QPointF maxXPt(image_width * scale / 2, image_height * scale / 2);
@@ -1517,7 +1568,7 @@ QPixmap &FITSView::getTrackingBoxPixmap(uint8_t margin)
     int w  = (trackingBox.width() + margin * 2) * scale;
     int h  = (trackingBox.height() + margin * 2) * scale;
 
-    trackingBoxPixmap = image_frame->grab(QRect(x1, y1, w, h));
+    trackingBoxPixmap = m_ImageFrame->grab(QRect(x1, y1, w, h));
     return trackingBoxPixmap;
 }
 
@@ -1586,14 +1637,14 @@ void FITSView::toggleEQGrid()
 {
     showEQGrid = !showEQGrid;
 
-    if (imageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
+    if (m_ImageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
     {
-        QFuture<bool> future = QtConcurrent::run(imageData.data(), &FITSData::loadWCS, true);
+        QFuture<bool> future = QtConcurrent::run(m_ImageData.data(), &FITSData::loadWCS, true);
         wcsWatcher.setFuture(future);
         return;
     }
 
-    if (image_frame != nullptr)
+    if (m_ImageFrame)
         updateFrame();
 }
 
@@ -1601,28 +1652,28 @@ void FITSView::toggleObjects()
 {
     showObjects = !showObjects;
 
-    if (imageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
+    if (m_ImageData->getWCSState() == FITSData::Idle && !wcsWatcher.isRunning())
     {
-        QFuture<bool> future = QtConcurrent::run(imageData.data(), &FITSData::loadWCS, true);
+        QFuture<bool> future = QtConcurrent::run(m_ImageData.data(), &FITSData::loadWCS, true);
         wcsWatcher.setFuture(future);
         return;
     }
 
-    if (image_frame != nullptr)
+    if (m_ImageFrame)
         updateFrame();
 }
 
 void FITSView::toggleStars()
 {
     toggleStars(!markStars);
-    if (image_frame != nullptr)
+    if (m_ImageFrame)
         updateFrame();
 }
 
 void FITSView::toggleStretch()
 {
     stretchImage = !stretchImage;
-    if (image_frame != nullptr && rescale(ZOOM_KEEP_LEVEL))
+    if (m_ImageFrame && rescale(ZOOM_KEEP_LEVEL))
         updateFrame();
 }
 
@@ -1708,21 +1759,21 @@ void FITSView::viewStarProfile()
         if(mode == FITS_ALIGN || mode == FITS_NORMAL)
         {
             starProfileWidget->enableTrackingBox(true);
-            imageData->setStarAlgorithm(ALGORITHM_CENTROID);
+            m_ImageData->setStarAlgorithm(ALGORITHM_CENTROID);
             connect(starProfileWidget, SIGNAL(sampleSizeUpdated(int)), this, SLOT(resizeTrackingBox(int)));
         }
     }
-    QList<Edge *> starCenters = imageData->getStarCentersInSubFrame(trackingBox);
+    QList<Edge *> starCenters = m_ImageData->getStarCentersInSubFrame(trackingBox);
     if(starCenters.size() == 0)
     {
         // FIXME, the following does not work anymore.
-        //imageData->findStars(&trackingBox, true);
+        //m_ImageData->findStars(&trackingBox, true);
         // FIXME replacing it with this
-        imageData->findStars(ALGORITHM_CENTROID, trackingBox).waitForFinished();
-        starCenters = imageData->getStarCentersInSubFrame(trackingBox);
+        m_ImageData->findStars(ALGORITHM_CENTROID, trackingBox).waitForFinished();
+        starCenters = m_ImageData->getStarCentersInSubFrame(trackingBox);
     }
 
-    starProfileWidget->loadData(imageData, trackingBox, starCenters);
+    starProfileWidget->loadData(m_ImageData, trackingBox, starCenters);
     starProfileWidget->show();
     starProfileWidget->raise();
     if(markStars)
@@ -1742,46 +1793,44 @@ void FITSView::togglePixelGrid()
 QFuture<bool> FITSView::findStars(StarAlgorithm algorithm, const QRect &searchBox)
 {
     if(trackingBoxEnabled)
-        return imageData->findStars(algorithm, trackingBox);
+        return m_ImageData->findStars(algorithm, trackingBox);
     else
-        return imageData->findStars(algorithm, searchBox);
+        return m_ImageData->findStars(algorithm, searchBox);
 }
 
 void FITSView::toggleStars(bool enable)
 {
     markStars = enable;
 
-    if (markStars && !imageData->areStarsSearched())
+    if (markStars)
         searchStars();
 }
 
 void FITSView::searchStars()
 {
     QVariant frameType;
-    if (!imageData || (imageData->getRecordValue("FRAME", frameType) && frameType.toString() != "Light"))
+    if (m_ImageData->areStarsSearched() || !m_ImageData || (m_ImageData->getRecordValue("FRAME", frameType)
+            && frameType.toString() != "Light"))
         return;
 
-    if (!imageData->areStarsSearched())
-    {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
-        emit newStatus(i18n("Finding stars..."), FITS_MESSAGE);
-        qApp->processEvents();
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+    emit newStatus(i18n("Finding stars..."), FITS_MESSAGE);
+    qApp->processEvents();
 
 #ifdef HAVE_STELLARSOLVER
-        QVariantMap extractionSettings;
-        extractionSettings["optionsProfileIndex"] = Options::hFROptionsProfile();
-        extractionSettings["optionsProfileGroup"] = static_cast<int>(Ekos::HFRProfiles);
-        getImageData()->setSourceExtractorSettings(extractionSettings);
+    QVariantMap extractionSettings;
+    extractionSettings["optionsProfileIndex"] = Options::hFROptionsProfile();
+    extractionSettings["optionsProfileGroup"] = static_cast<int>(Ekos::HFRProfiles);
+    getImageData()->setSourceExtractorSettings(extractionSettings);
 #endif
 
-        QFuture<bool> result = findStars(ALGORITHM_SEP);
-        result.waitForFinished();
-        if (result.result() && isVisible())
-        {
-            emit newStatus("", FITS_MESSAGE);
-        }
-        QApplication::restoreOverrideCursor();
+    QFuture<bool> result = findStars(ALGORITHM_SEP);
+    result.waitForFinished();
+    if (result.result() && isVisible())
+    {
+        emit newStatus("", FITS_MESSAGE);
     }
+    QApplication::restoreOverrideCursor();
 }
 
 void FITSView::processPointSelection(int x, int y)
@@ -1879,10 +1928,10 @@ void FITSView::initDisplayImage()
 {
     // Account for leftover when sampling. Thus a 5-wide image sampled by 2
     // would result in a width of 3 (samples 0, 2 and 4).
-    int w = (imageData->width() + m_PreviewSampling - 1) / m_PreviewSampling;
-    int h = (imageData->height() + m_PreviewSampling - 1) / m_PreviewSampling;
+    int w = (m_ImageData->width() + m_PreviewSampling - 1) / m_PreviewSampling;
+    int h = (m_ImageData->height() + m_PreviewSampling - 1) / m_PreviewSampling;
 
-    if (imageData->channels() == 1)
+    if (m_ImageData->channels() == 1)
     {
         rawImage = QImage(w, h, QImage::Format_Indexed8);
 
@@ -1949,15 +1998,15 @@ void FITSView::pinchTriggered(QPinchGesture * gesture)
 /*void FITSView::handleWCSCompletion()
 {
     //bool hasWCS = wcsWatcher.result();
-    if(imageData->hasWCS())
+    if(m_ImageData->hasWCS())
         this->updateFrame();
-    emit wcsToggled(imageData->hasWCS());
+    emit wcsToggled(m_ImageData->hasWCS());
 }*/
 
 void FITSView::syncWCSState()
 {
-    bool hasWCS    = imageData->hasWCS();
-    bool wcsLoaded = imageData->getWCSState() == FITSData::Success;
+    bool hasWCS    = m_ImageData->hasWCS();
+    bool wcsLoaded = m_ImageData->getWCSState() == FITSData::Success;
 
     if (hasWCS && wcsLoaded)
         this->updateFrame();
