@@ -38,7 +38,7 @@
 #include <KNotifications/KStatusNotifierItem>
 
 #ifndef KSTARS_LITE
-#include "fitshistogram.h"
+#include "fitshistogrameditor.h"
 #endif
 
 #include <fits_debug.h>
@@ -96,7 +96,7 @@ FITSViewer::FITSViewer(QWidget *parent) : KXmlGuiWindow(parent)
 
     fitsWCS.setVisible(false);
 
-    statusBar()->insertPermanentWidget(FITS_ZOOM, &fitsHFR);
+    statusBar()->insertPermanentWidget(FITS_HFR, &fitsHFR);
     statusBar()->insertPermanentWidget(FITS_WCS, &fitsWCS);
     statusBar()->insertPermanentWidget(FITS_VALUE, &fitsValue);
     statusBar()->insertPermanentWidget(FITS_POSITION, &fitsPosition);
@@ -642,7 +642,7 @@ void FITSViewer::openFile()
     QUrl fileURL = QFileDialog::getOpenFileUrl(KStars::Instance(), i18n("Open Image"), lastURL,
                    "Images (*.fits *.fits.fz *.fit *.fts "
                    "*.jpg *.jpeg *.png *.gif *.bmp "
-                   "*.cr2 *.cr3 *.crw *.nef *.raf *.dng *.arw)");
+                   "*.cr2 *.cr3 *.crw *.nef *.raf *.dng *.arw *.orf)");
 
     if (fileURL.isEmpty())
         return;
