@@ -33,7 +33,7 @@
 
 #include <basedevice.h>
 
-const QStringList RAWFormats = { "cr2", "cr3", "crw", "nef", "raf", "dng", "arw" };
+const QStringList RAWFormats = { "cr2", "cr3", "crw", "nef", "raf", "dng", "arw", "orf" };
 
 namespace
 {
@@ -77,8 +77,7 @@ void addFITSKeywords(const QString &filename, const QString &filter_used)
 }
 
 // Internal function to write an image blob to disk.
-bool WriteImageFileInternal(const QString &filename, char *buffer, const size_t size,
-                            bool add_fits_keywords, const QString &filter)
+bool WriteImageFileInternal(const QString &filename, char *buffer, const size_t size)
 {
     QFile file(filename);
     if (!file.open(QIODevice::WriteOnly))
@@ -97,8 +96,8 @@ bool WriteImageFileInternal(const QString &filename, char *buffer, const size_t
                         QFileDevice::WriteUser |
                         QFileDevice::ReadGroup |
                         QFileDevice::ReadOther);
-    if (add_fits_keywords)
-        addFITSKeywords(filename, filter);
+    //    if (add_fits_keywords)
+    //        addFITSKeywords(filename, filter);
     return true;
 }
 }
@@ -1466,14 +1465,12 @@ bool CCD::writeImageFile(const QString &filename, IBLOB *bp, bool is_fits)
         // Copy memory, and write file on a separate thread.
         // Probably too late to return an error if the file couldn't write.
         memcpy(fileWriteBuffer, bp->blob, bp->size);
-        fileWriteThread = QtConcurrent::run(WriteImageFileInternal, fileWriteFilename,
-                                            fileWriteBuffer, bp->size, is_fits, filter);
-        filter = "";
+        fileWriteThread = QtConcurrent::run(WriteImageFileInternal, fileWriteFilename, fileWriteBuffer, bp->size);
+        //filter = "";
     }
     else
     {
-        if (!WriteImageFileInternal(filename, static_cast<char*>(bp->blob), bp->size,
-                                    false, filter))
+        if (!WriteImageFileInternal(filename, static_cast<char*>(bp->blob), bp->size))
             return false;
     }
     return true;
@@ -2172,12 +2169,14 @@ bool CCD::setTelescopeType(TelescopeType type)
 
     telescopeType = type;
 
-    typePrimary->s = (telescopeType == TELESCOPE_PRIMARY) ? ISS_ON : ISS_OFF;
-    typeGuide->s   = (telescopeType == TELESCOPE_PRIMARY) ? ISS_OFF : ISS_ON;
-
-    clientManager->sendNewSwitch(svp);
-
-    setConfig(SAVE_CONFIG);
+    if ( (telescopeType == TELESCOPE_PRIMARY && typePrimary->s == ISS_OFF) ||
+            (telescopeType == TELESCOPE_GUIDE && typeGuide->s == ISS_OFF))
+    {
+        typePrimary->s = (telescopeType == TELESCOPE_PRIMARY) ? ISS_ON : ISS_OFF;
+        typeGuide->s   = (telescopeType == TELESCOPE_PRIMARY) ? ISS_OFF : ISS_ON;
+        clientManager->sendNewSwitch(svp);
+        setConfig(SAVE_CONFIG);
+    }
 
     return true;
 }
@@ -2238,7 +2237,7 @@ bool CCD::resetStreamingFrame()
 
 bool CCD::setStreamLimits(uint16_t maxBufferSize, uint16_t maxPreviewFPS)
 {
-    INumberVectorProperty *limitsProp = baseDevice->getNumber("CCD_STREAM_FRAME");
+    INumberVectorProperty *limitsProp = baseDevice->getNumber("LIMITS");
 
     if (limitsProp == nullptr)
         return false;
@@ -2248,12 +2247,13 @@ bool CCD::setStreamLimits(uint16_t maxBufferSize, uint16_t maxPreviewFPS)
 
     if (bufferMax && previewFPS)
     {
-        if(std::fabs(bufferMax->value - maxBufferSize) == 0 && std::fabs(previewFPS->value - maxPreviewFPS) == 0)
-            return true;
+        if(std::fabs(bufferMax->value - maxBufferSize) > 0 || std::fabs(previewFPS->value - maxPreviewFPS) > 0)
+        {
+            bufferMax->value = maxBufferSize;
+            previewFPS->value = maxPreviewFPS;
+            clientManager->sendNewNumber(limitsProp);
+        }
 
-        bufferMax->value = maxBufferSize;
-        previewFPS->value = maxPreviewFPS;
-        clientManager->sendNewNumber(limitsProp);
         return true;
     }
 
