@@ -39,6 +39,7 @@
 #include "options/opscatalog.h"
 #include "options/opscolors.h"
 #include "options/opsguides.h"
+#include "options/opsterrain.h"
 #include "options/opssatellites.h"
 #include "options/opssolarsystem.h"
 #include "options/opssupernovae.h"
@@ -1035,6 +1036,7 @@ KConfigDialog* KStars::prepareOps()
 
     opcatalog     = new OpsCatalog();
     opguides      = new OpsGuides();
+    opterrain     = new OpsTerrain();
     opsolsys      = new OpsSolarSystem();
     opssatellites = new OpsSatellites();
     opssupernovae = new OpsSupernovae();
@@ -1058,6 +1060,10 @@ KConfigDialog* KStars::prepareOps()
     page = dialog->addPage(opguides, i18n("Guides"), "kstars_guides");
     page->setIcon(QIcon::fromTheme("kstars_guides"));
 
+    page = dialog->addPage(opterrain, i18n("Terrain"), "kstars_terrain");
+    page->setIcon(QIcon::fromTheme("kstars_terrain", QIcon(":/icons/kstars_terrain.png")));
+
+
     page = dialog->addPage(opcolors, i18n("Colors"), "kstars_colors");
     page->setIcon(QIcon::fromTheme("kstars_colors"));
 
@@ -1091,6 +1097,13 @@ KConfigDialog* KStars::prepareOps()
     return dialog;
 }
 
+void KStars::syncOps()
+{
+    opterrain->syncOptions();
+    actionCollection()->action("toggle_terrain")
+    ->setText(Options::showTerrain() ? i18n("Hide Terrain") : i18n("Show Terrain"));
+}
+
 void KStars::slotApplyConfigChanges()
 {
     Options::self()->save();
@@ -1192,7 +1205,7 @@ void KStars::slotOpenFITS()
     QUrl fileURL = QFileDialog::getOpenFileUrl(KStars::Instance(), i18n("Open Image"), path,
                    "Images (*.fits *.fits.fz *.fit *.fts "
                    "*.jpg *.jpeg *.png *.gif *.bmp "
-                   "*.cr2 *.cr3 *.crw *.nef *.raf *.dng *.arw)");
+                   "*.cr2 *.cr3 *.crw *.nef *.raf *.dng *.arw *.orf)");
     if (fileURL.isEmpty())
         return;
 
@@ -1773,6 +1786,15 @@ void KStars::slotFullScreen()
     }
 }
 
+// Toggle to and from full screen mode
+void KStars::slotTerrain()
+{
+    Options::setShowTerrain(!Options::showTerrain());
+    actionCollection()->action("toggle_terrain")
+    ->setText(Options::showTerrain() ? i18n("Hide terrain") : i18n("Show terrain"));
+    KStars::Instance()->map()->forceUpdate();
+}
+
 void KStars::slotClearAllTrails()
 {
     //Exclude object with temporary trail
