@@ -416,7 +416,7 @@ bool Projector::unusablePoint(const QPointF &p) const
     return (dx * dx + dy * dy) > r0 * r0;
 }
 
-SkyPoint Projector::fromScreen(const QPointF &p, dms *LST, const dms *lat) const
+SkyPoint Projector::fromScreen(const QPointF &p, dms *LST, const dms *lat, bool onlyAltAz) const
 {
     dms c;
     double sinc, cosc;
@@ -457,6 +457,8 @@ SkyPoint Projector::fromScreen(const QPointF &p, dms *LST, const dms *lat) const
             alt = SkyPoint::unrefract(alt);
         result.setAlt(alt);
         result.setAz(az);
+        if (onlyAltAz)
+            return result;
         result.HorizontalToEquatorial(LST, lat);
     }
     else
