@@ -58,6 +58,7 @@
 #include "observinglist.h"
 #include "skymap.h"
 #include "hipscomponent.h"
+#include "terraincomponent.h"
 #endif
 
 #include <QApplication>
@@ -151,6 +152,8 @@ SkyMapComposite::SkyMapComposite(SkyComposite *parent) : SkyComposite(parent), m
     // Hips
     addComponent(m_HiPS = new HIPSComponent(this));
 
+    addComponent(m_Terrain = new TerrainComponent(this));
+
     addComponent(m_ArtificialHorizon = new ArtificialHorizonComponent(this), 110);
 
     m_internetResolvedCat = "_Internet_Resolved";
@@ -374,6 +377,9 @@ void SkyMapComposite::draw(SkyPainter *skyp)
 
     m_skyMesh->inDraw(false);
 
+    // Draw terrain at the end.
+    m_Terrain->draw(skyp);
+
     // DEBUG Edit. Keywords: Trixel boundaries. Currently works only in QPainter mode
     // -jbb uncomment these to see trixel outlines:
     /*
