@@ -482,10 +482,11 @@ bool StarComponent::loadStaticData()
         Trixel trixel = i; // = ( ( i >= 256 ) ? ( i - 256 ) : ( i + 256 ) );
         for (unsigned long j = 0; j < static_cast<unsigned long>(dataReader.getRecordCount(i)); ++j)
         {
-            if (!fread(&stardata, sizeof(StarData), 1, dataFile))
+            if (1 != fread(&stardata, sizeof(StarData), 1, dataFile))
             {
                 qCCritical(KSTARS) << "FILE FORMAT ERROR: Could not read StarData structure for star #" << j << " under trixel #"
                                    << trixel;
+                continue;
             }
 
             /* Swap Bytes when required */
@@ -499,7 +500,7 @@ bool StarComponent::loadStaticData()
             if (stardata.flags & 0x01)
             {
                 visibleName = "";
-                if (!fread(&starname, sizeof(starName), 1, nameFile))
+                if (1 != fread(&starname, sizeof(starName), 1, nameFile))
                     qCCritical(KSTARS) << "ERROR: fread() call on nameFile failed in trixel " << trixel << " star " << j;
 
                 name  = QByteArray(starname.longName, 32);
