@@ -37,7 +37,7 @@
 #include <cmath>
 
 #ifdef HAVE_LIBNOVA
-#include <libnova.h>
+#include <libnova/libnova.h>
 #endif
 #ifdef PROFILE_COORDINATE_CONVERSION
 #include <ctime> // For profiling, remove if not profiling.
@@ -107,7 +107,7 @@ void SkyPoint::EquatorialToHorizontal(const CachingDms *LST, const CachingDms *l
     else
         AzRad = acos(arg);
 
-    if (sinHA > 0.0)
+    if (sinHA > 0.0 && AzRad != 0.0)
         AzRad = 2.0 * dms::PI - AzRad; // resolve acos() ambiguity
 
     Alt.setRadians(AltRad);
